from . import models as models
from .const import GROUP_ID_ADMIN as GROUP_ID_ADMIN, GROUP_ID_READ_ONLY as GROUP_ID_READ_ONLY, GROUP_ID_USER as GROUP_ID_USER
from .permissions import PermissionLookup as PermissionLookup, system_policies as system_policies
from .permissions.types import PolicyType as PolicyType
from datetime import timedelta
from homeassistant.auth.const import ACCESS_TOKEN_EXPIRATION as ACCESS_TOKEN_EXPIRATION
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from typing import Any

STORAGE_VERSION: int
STORAGE_KEY: str
GROUP_NAME_ADMIN: str
GROUP_NAME_USER: str
GROUP_NAME_READ_ONLY: str

class AuthStore:
    hass: Any
    _users: Any
    _groups: Any
    _perm_lookup: Any
    _store: Any
    _lock: Any
    def __init__(self, hass: HomeAssistant) -> None: ...
    async def async_get_groups(self) -> list[models.Group]: ...
    async def async_get_group(self, group_id: str) -> Union[models.Group, None]: ...
    async def async_get_users(self) -> list[models.User]: ...
    async def async_get_user(self, user_id: str) -> Union[models.User, None]: ...
    async def async_create_user(self, name: Union[str, None], is_owner: Union[bool, None] = ..., is_active: Union[bool, None] = ..., system_generated: Union[bool, None] = ..., credentials: Union[models.Credentials, None] = ..., group_ids: Union[list[str], None] = ...) -> models.User: ...
    async def async_link_user(self, user: models.User, credentials: models.Credentials) -> None: ...
    async def async_remove_user(self, user: models.User) -> None: ...
    async def async_update_user(self, user: models.User, name: Union[str, None] = ..., is_active: Union[bool, None] = ..., group_ids: Union[list[str], None] = ...) -> None: ...
    async def async_activate_user(self, user: models.User) -> None: ...
    async def async_deactivate_user(self, user: models.User) -> None: ...
    async def async_remove_credentials(self, credentials: models.Credentials) -> None: ...
    async def async_create_refresh_token(self, user: models.User, client_id: Union[str, None] = ..., client_name: Union[str, None] = ..., client_icon: Union[str, None] = ..., token_type: str = ..., access_token_expiration: timedelta = ..., credential: Union[models.Credentials, None] = ...) -> models.RefreshToken: ...
    async def async_remove_refresh_token(self, refresh_token: models.RefreshToken) -> None: ...
    async def async_get_refresh_token(self, token_id: str) -> Union[models.RefreshToken, None]: ...
    async def async_get_refresh_token_by_token(self, token: str) -> Union[models.RefreshToken, None]: ...
    def async_log_refresh_token_usage(self, refresh_token: models.RefreshToken, remote_ip: Union[str, None] = ...) -> None: ...
    async def _async_load(self) -> None: ...
    async def _async_load_task(self) -> None: ...
    def _async_schedule_save(self) -> None: ...
    def _data_to_save(self) -> dict: ...
    def _set_defaults(self) -> None: ...

def _system_admin_group() -> models.Group: ...
def _system_user_group() -> models.Group: ...
def _system_read_only_group() -> models.Group: ...



from .const import ADD_TRACKING_SERVICE_SCHEMA as ADD_TRACKING_SERVICE_SCHEMA, ATTRIBUTION as ATTRIBUTION, ATTR_TRACKINGS as ATTR_TRACKINGS, BASE as BASE, CONF_SLUG as CONF_SLUG, CONF_TITLE as CONF_TITLE, CONF_TRACKING_NUMBER as CONF_TRACKING_NUMBER, DEFAULT_NAME as DEFAULT_NAME, DOMAIN as DOMAIN, ICON as ICON, MIN_TIME_BETWEEN_UPDATES as MIN_TIME_BETWEEN_UPDATES, REMOVE_TRACKING_SERVICE_SCHEMA as REMOVE_TRACKING_SERVICE_SCHEMA, SERVICE_ADD_TRACKING as SERVICE_ADD_TRACKING, SERVICE_REMOVE_TRACKING as SERVICE_REMOVE_TRACKING, UPDATE_TOPIC as UPDATE_TOPIC
from homeassistant.components.sensor import SensorEntity as SensorEntity
from homeassistant.const import ATTR_ATTRIBUTION as ATTR_ATTRIBUTION, CONF_API_KEY as CONF_API_KEY, CONF_NAME as CONF_NAME, HTTP_OK as HTTP_OK
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.aiohttp_client import async_get_clientsession as async_get_clientsession
from homeassistant.helpers.dispatcher import async_dispatcher_send as async_dispatcher_send
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.service import ServiceCall as ServiceCall
from homeassistant.helpers.typing import ConfigType as ConfigType, DiscoveryInfoType as DiscoveryInfoType
from homeassistant.util import Throttle as Throttle
from pyaftership.tracker import Tracking
from typing import Any, Final

_LOGGER: Final[Any]
PLATFORM_SCHEMA: Final[Any]

async def async_setup_platform(hass: HomeAssistant, config: ConfigType, async_add_entities: AddEntitiesCallback, discovery_info: Union[DiscoveryInfoType, None] = ...) -> None: ...

class AfterShipSensor(SensorEntity):
    _attr_unit_of_measurement: str
    _attr_icon: str
    _attributes: Any
    _state: Any
    aftership: Any
    _attr_name: Any
    def __init__(self, aftership: Tracking, name: str) -> None: ...
    @property
    def state(self) -> Union[int, None]: ...
    @property
    def extra_state_attributes(self) -> dict[str, str]: ...
    async def async_added_to_hass(self) -> None: ...
    async def _force_update(self) -> None: ...
    async def async_update(self, **kwargs: Any) -> None: ...



from .const import CONF_MOUNT_DIR as CONF_MOUNT_DIR, CONF_NAMES as CONF_NAMES, CONF_TYPE_OWSERVER as CONF_TYPE_OWSERVER, CONF_TYPE_SYSBUS as CONF_TYPE_SYSBUS, DEFAULT_OWSERVER_PORT as DEFAULT_OWSERVER_PORT, DEFAULT_SYSBUS_MOUNT_DIR as DEFAULT_SYSBUS_MOUNT_DIR, DOMAIN as DOMAIN, SENSOR_TYPE_COUNT as SENSOR_TYPE_COUNT, SENSOR_TYPE_CURRENT as SENSOR_TYPE_CURRENT, SENSOR_TYPE_HUMIDITY as SENSOR_TYPE_HUMIDITY, SENSOR_TYPE_ILLUMINANCE as SENSOR_TYPE_ILLUMINANCE, SENSOR_TYPE_MOISTURE as SENSOR_TYPE_MOISTURE, SENSOR_TYPE_PRESSURE as SENSOR_TYPE_PRESSURE, SENSOR_TYPE_TEMPERATURE as SENSOR_TYPE_TEMPERATURE, SENSOR_TYPE_VOLTAGE as SENSOR_TYPE_VOLTAGE, SENSOR_TYPE_WETNESS as SENSOR_TYPE_WETNESS
from .model import DeviceComponentDescription as DeviceComponentDescription
from .onewire_entities import OneWireBaseEntity as OneWireBaseEntity, OneWireProxyEntity as OneWireProxyEntity
from .onewirehub import OneWireHub as OneWireHub
from homeassistant.components.sensor import PLATFORM_SCHEMA as PLATFORM_SCHEMA, SensorEntity as SensorEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry, SOURCE_IMPORT as SOURCE_IMPORT
from homeassistant.const import CONF_HOST as CONF_HOST, CONF_PORT as CONF_PORT, CONF_TYPE as CONF_TYPE
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity import DeviceInfo as DeviceInfo
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.typing import DiscoveryInfoType as DiscoveryInfoType, StateType as StateType
from pi1wire import OneWireInterface as OneWireInterface
from types import MappingProxyType
from typing import Any

_LOGGER: Any
DEVICE_SENSORS: dict[str, list[DeviceComponentDescription]]
DEVICE_SUPPORT_SYSBUS: Any
HOBBYBOARD_EF: dict[str, list[DeviceComponentDescription]]
EDS_SENSORS: dict[str, list[DeviceComponentDescription]]

def get_sensor_types(device_sub_type: str) -> dict[str, Any]: ...
async def async_setup_platform(hass: HomeAssistant, config: dict[str, Any], async_add_entities: AddEntitiesCallback, discovery_info: Union[DiscoveryInfoType, None] = ...) -> None: ...
async def async_setup_entry(hass: HomeAssistant, config_entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...
def get_entities(onewirehub: OneWireHub, config: MappingProxyType[str, Any]) -> list[OneWireBaseEntity]: ...

class OneWireSensor(OneWireBaseEntity, SensorEntity):
    @property
    def unit_of_measurement(self) -> Union[str, None]: ...

class OneWireProxySensor(OneWireProxyEntity, OneWireSensor):
    @property
    def state(self) -> StateType: ...

class OneWireDirectSensor(OneWireSensor):
    _owsensor: Any
    def __init__(self, name: str, device_file: str, device_info: DeviceInfo, owsensor: OneWireInterface) -> None: ...
    @property
    def state(self) -> StateType: ...
    async def get_temperature(self) -> float: ...
    _value_raw: Any
    _state: Any
    async def async_update(self) -> None: ...



from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.loader import bind_hass as bind_hass
from homeassistant.util.package import is_virtual_env as is_virtual_env
from typing import Any

async def async_get_system_info(hass: HomeAssistant) -> dict[str, Any]: ...



from . import RitualsDataUpdateCoordinator as RitualsDataUpdateCoordinator
from .const import COORDINATORS as COORDINATORS, DEVICES as DEVICES, DOMAIN as DOMAIN
from .entity import DiffuserEntity as DiffuserEntity
from homeassistant.components.switch import SwitchEntity as SwitchEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from pyrituals import Diffuser as Diffuser
from typing import Any

async def async_setup_entry(hass: HomeAssistant, config_entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class DiffuserSwitch(SwitchEntity, DiffuserEntity):
    _attr_icon: str
    _attr_is_on: Any
    def __init__(self, diffuser: Diffuser, coordinator: RitualsDataUpdateCoordinator) -> None: ...
    async def async_turn_on(self, **kwargs: Any) -> None: ...
    async def async_turn_off(self, **kwargs: Any) -> None: ...
    def _handle_coordinator_update(self) -> None: ...



from .const import DATA_CLIENT as DATA_CLIENT, DOMAIN as DOMAIN
from .discovery import ZwaveDiscoveryInfo as ZwaveDiscoveryInfo
from .entity import ZWaveBaseEntity as ZWaveBaseEntity
from homeassistant.components.cover import ATTR_POSITION as ATTR_POSITION, CoverEntity as CoverEntity, DEVICE_CLASS_BLIND as DEVICE_CLASS_BLIND, DEVICE_CLASS_GARAGE as DEVICE_CLASS_GARAGE, DEVICE_CLASS_SHUTTER as DEVICE_CLASS_SHUTTER, DEVICE_CLASS_WINDOW as DEVICE_CLASS_WINDOW, SUPPORT_CLOSE as SUPPORT_CLOSE, SUPPORT_OPEN as SUPPORT_OPEN
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.dispatcher import async_dispatcher_connect as async_dispatcher_connect
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from typing import Any
from zwave_js_server.client import Client as ZwaveClient

LOGGER: Any

async def async_setup_entry(hass: HomeAssistant, config_entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...
def percent_to_zwave_position(value: int) -> int: ...

class ZWaveCover(ZWaveBaseEntity, CoverEntity):
    _attr_device_class: Any
    def __init__(self, config_entry: ConfigEntry, client: ZwaveClient, info: ZwaveDiscoveryInfo) -> None: ...
    @property
    def is_closed(self) -> Union[bool, None]: ...
    @property
    def current_cover_position(self) -> Union[int, None]: ...
    async def async_set_cover_position(self, **kwargs: Any) -> None: ...
    async def async_open_cover(self, **kwargs: Any) -> None: ...
    async def async_close_cover(self, **kwargs: Any) -> None: ...
    async def async_stop_cover(self, **kwargs: Any) -> None: ...

class ZwaveMotorizedBarrier(ZWaveBaseEntity, CoverEntity):
    _attr_supported_features: Any
    _attr_device_class: Any
    _target_state: Any
    def __init__(self, config_entry: ConfigEntry, client: ZwaveClient, info: ZwaveDiscoveryInfo) -> None: ...
    @property
    def is_opening(self) -> Union[bool, None]: ...
    @property
    def is_closing(self) -> Union[bool, None]: ...
    @property
    def is_closed(self) -> Union[bool, None]: ...
    async def async_open_cover(self, **kwargs: Any) -> None: ...
    async def async_close_cover(self, **kwargs: Any) -> None: ...



from .climate_sdm import async_setup_sdm_entry as async_setup_sdm_entry
from .const import DATA_SDM as DATA_SDM
from .legacy.climate import async_setup_legacy_entry as async_setup_legacy_entry
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...



from . import api as api, config_flow as config_flow
from .const import DATA_SDM as DATA_SDM, DATA_SUBSCRIBER as DATA_SUBSCRIBER, DOMAIN as DOMAIN, OAUTH2_AUTHORIZE as OAUTH2_AUTHORIZE, OAUTH2_TOKEN as OAUTH2_TOKEN
from .events import EVENT_NAME_MAP as EVENT_NAME_MAP, NEST_EVENT as NEST_EVENT
from .legacy import async_setup_legacy as async_setup_legacy, async_setup_legacy_entry as async_setup_legacy_entry
from google_nest_sdm.event import EventMessage as EventMessage
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import CONF_BINARY_SENSORS as CONF_BINARY_SENSORS, CONF_CLIENT_ID as CONF_CLIENT_ID, CONF_CLIENT_SECRET as CONF_CLIENT_SECRET, CONF_MONITORED_CONDITIONS as CONF_MONITORED_CONDITIONS, CONF_SENSORS as CONF_SENSORS, CONF_STRUCTURE as CONF_STRUCTURE
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.exceptions import ConfigEntryAuthFailed as ConfigEntryAuthFailed, ConfigEntryNotReady as ConfigEntryNotReady
from homeassistant.helpers import aiohttp_client as aiohttp_client, config_entry_oauth2_flow as config_entry_oauth2_flow
from typing import Any

_LOGGER: Any
CONF_PROJECT_ID: str
CONF_SUBSCRIBER_ID: str
DATA_NEST_CONFIG: str
DATA_NEST_UNAVAILABLE: str
NEST_SETUP_NOTIFICATION: str
SENSOR_SCHEMA: Any
CONFIG_SCHEMA: Any
PLATFORMS: Any

async def async_setup(hass: HomeAssistant, config: dict) -> bool: ...

class SignalUpdateCallback:
    _hass: Any
    def __init__(self, hass: HomeAssistant) -> None: ...
    async def async_handle_event(self, event_message: EventMessage) -> None: ...

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...
async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...



import voluptuous as vol
from .const import CONF_INVERT as CONF_INVERT, CONF_KNX_EXPOSE as CONF_KNX_EXPOSE, CONF_KNX_INDIVIDUAL_ADDRESS as CONF_KNX_INDIVIDUAL_ADDRESS, CONF_KNX_ROUTING as CONF_KNX_ROUTING, CONF_KNX_TUNNELING as CONF_KNX_TUNNELING, CONF_RESET_AFTER as CONF_RESET_AFTER, CONF_RESPOND_TO_READ as CONF_RESPOND_TO_READ, CONF_STATE_ADDRESS as CONF_STATE_ADDRESS, CONF_SYNC_STATE as CONF_SYNC_STATE, CONTROLLER_MODES as CONTROLLER_MODES, ColorTempModes as ColorTempModes, KNX_ADDRESS as KNX_ADDRESS, PRESET_MODES as PRESET_MODES, SupportedPlatforms as SupportedPlatforms
from abc import ABC
from collections import OrderedDict
from homeassistant.const import CONF_DEVICE_CLASS as CONF_DEVICE_CLASS, CONF_ENTITY_ID as CONF_ENTITY_ID, CONF_HOST as CONF_HOST, CONF_NAME as CONF_NAME, CONF_PORT as CONF_PORT, CONF_TYPE as CONF_TYPE
from typing import Any, ClassVar

def ga_validator(value: Any) -> Union[str, int]: ...

ga_list_validator: Any
ia_validator: Any

def number_limit_sub_validator(entity_config: OrderedDict) -> OrderedDict: ...
def numeric_type_validator(value: Any) -> Union[str, int]: ...
def select_options_sub_validator(entity_config: OrderedDict) -> OrderedDict: ...
def sensor_type_validator(value: Any) -> Union[str, int]: ...

sync_state_validator: Any

class ConnectionSchema:
    CONF_KNX_LOCAL_IP: str
    CONF_KNX_MCAST_GRP: str
    CONF_KNX_MCAST_PORT: str
    CONF_KNX_RATE_LIMIT: str
    CONF_KNX_ROUTE_BACK: str
    CONF_KNX_STATE_UPDATER: str
    TUNNELING_SCHEMA: Any
    ROUTING_SCHEMA: Any
    SCHEMA: Any

class KNXPlatformSchema(ABC):
    PLATFORM_NAME: ClassVar[str]
    ENTITY_SCHEMA: ClassVar[vol.Schema]
    @classmethod
    def platform_node(cls) -> dict[vol.Optional, vol.All]: ...

class BinarySensorSchema(KNXPlatformSchema):
    PLATFORM_NAME: Any
    CONF_STATE_ADDRESS: Any
    CONF_SYNC_STATE: Any
    CONF_INVERT: Any
    CONF_IGNORE_INTERNAL_STATE: str
    CONF_CONTEXT_TIMEOUT: str
    CONF_RESET_AFTER: Any
    DEFAULT_NAME: str
    ENTITY_SCHEMA: Any

class ClimateSchema(KNXPlatformSchema):
    PLATFORM_NAME: Any
    CONF_ACTIVE_STATE_ADDRESS: str
    CONF_SETPOINT_SHIFT_ADDRESS: str
    CONF_SETPOINT_SHIFT_STATE_ADDRESS: str
    CONF_SETPOINT_SHIFT_MODE: str
    CONF_SETPOINT_SHIFT_MAX: str
    CONF_SETPOINT_SHIFT_MIN: str
    CONF_TEMPERATURE_ADDRESS: str
    CONF_TEMPERATURE_STEP: str
    CONF_TARGET_TEMPERATURE_ADDRESS: str
    CONF_TARGET_TEMPERATURE_STATE_ADDRESS: str
    CONF_OPERATION_MODE_ADDRESS: str
    CONF_OPERATION_MODE_STATE_ADDRESS: str
    CONF_CONTROLLER_STATUS_ADDRESS: str
    CONF_CONTROLLER_STATUS_STATE_ADDRESS: str
    CONF_CONTROLLER_MODE_ADDRESS: str
    CONF_CONTROLLER_MODE_STATE_ADDRESS: str
    CONF_COMMAND_VALUE_STATE_ADDRESS: str
    CONF_HEAT_COOL_ADDRESS: str
    CONF_HEAT_COOL_STATE_ADDRESS: str
    CONF_OPERATION_MODE_FROST_PROTECTION_ADDRESS: str
    CONF_OPERATION_MODE_NIGHT_ADDRESS: str
    CONF_OPERATION_MODE_COMFORT_ADDRESS: str
    CONF_OPERATION_MODE_STANDBY_ADDRESS: str
    CONF_OPERATION_MODES: str
    CONF_CONTROLLER_MODES: str
    CONF_ON_OFF_ADDRESS: str
    CONF_ON_OFF_STATE_ADDRESS: str
    CONF_ON_OFF_INVERT: str
    CONF_MIN_TEMP: str
    CONF_MAX_TEMP: str
    DEFAULT_NAME: str
    DEFAULT_SETPOINT_SHIFT_MODE: str
    DEFAULT_SETPOINT_SHIFT_MAX: int
    DEFAULT_SETPOINT_SHIFT_MIN: int
    DEFAULT_TEMPERATURE_STEP: float
    DEFAULT_ON_OFF_INVERT: bool
    ENTITY_SCHEMA: Any

class CoverSchema(KNXPlatformSchema):
    PLATFORM_NAME: Any
    CONF_MOVE_LONG_ADDRESS: str
    CONF_MOVE_SHORT_ADDRESS: str
    CONF_STOP_ADDRESS: str
    CONF_POSITION_ADDRESS: str
    CONF_POSITION_STATE_ADDRESS: str
    CONF_ANGLE_ADDRESS: str
    CONF_ANGLE_STATE_ADDRESS: str
    CONF_TRAVELLING_TIME_DOWN: str
    CONF_TRAVELLING_TIME_UP: str
    CONF_INVERT_POSITION: str
    CONF_INVERT_ANGLE: str
    DEFAULT_TRAVEL_TIME: int
    DEFAULT_NAME: str
    ENTITY_SCHEMA: Any

class ExposeSchema(KNXPlatformSchema):
    PLATFORM_NAME: Any
    CONF_KNX_EXPOSE_TYPE: Any
    CONF_KNX_EXPOSE_ATTRIBUTE: str
    CONF_KNX_EXPOSE_BINARY: str
    CONF_KNX_EXPOSE_DEFAULT: str
    EXPOSE_TIME_TYPES: Any
    EXPOSE_TIME_SCHEMA: Any
    EXPOSE_SENSOR_SCHEMA: Any
    ENTITY_SCHEMA: Any

class FanSchema(KNXPlatformSchema):
    PLATFORM_NAME: Any
    CONF_STATE_ADDRESS: Any
    CONF_OSCILLATION_ADDRESS: str
    CONF_OSCILLATION_STATE_ADDRESS: str
    CONF_MAX_STEP: str
    DEFAULT_NAME: str
    ENTITY_SCHEMA: Any

class LightSchema(KNXPlatformSchema):
    PLATFORM_NAME: Any
    CONF_STATE_ADDRESS: Any
    CONF_BRIGHTNESS_ADDRESS: str
    CONF_BRIGHTNESS_STATE_ADDRESS: str
    CONF_COLOR_ADDRESS: str
    CONF_COLOR_STATE_ADDRESS: str
    CONF_COLOR_TEMP_ADDRESS: str
    CONF_COLOR_TEMP_STATE_ADDRESS: str
    CONF_COLOR_TEMP_MODE: str
    CONF_HUE_ADDRESS: str
    CONF_HUE_STATE_ADDRESS: str
    CONF_RGBW_ADDRESS: str
    CONF_RGBW_STATE_ADDRESS: str
    CONF_SATURATION_ADDRESS: str
    CONF_SATURATION_STATE_ADDRESS: str
    CONF_XYY_ADDRESS: str
    CONF_XYY_STATE_ADDRESS: str
    CONF_MIN_KELVIN: str
    CONF_MAX_KELVIN: str
    DEFAULT_NAME: str
    DEFAULT_COLOR_TEMP_MODE: str
    DEFAULT_MIN_KELVIN: int
    DEFAULT_MAX_KELVIN: int
    CONF_INDIVIDUAL_COLORS: str
    CONF_RED: str
    CONF_GREEN: str
    CONF_BLUE: str
    CONF_WHITE: str
    _hs_color_inclusion_msg: str
    HS_COLOR_SCHEMA: Any
    INDIVIDUAL_COLOR_SCHEMA: Any
    ENTITY_SCHEMA: Any

class NotifySchema(KNXPlatformSchema):
    PLATFORM_NAME: Any
    DEFAULT_NAME: str
    ENTITY_SCHEMA: Any

class NumberSchema(KNXPlatformSchema):
    PLATFORM_NAME: Any
    CONF_MAX: str
    CONF_MIN: str
    CONF_STEP: str
    DEFAULT_NAME: str
    ENTITY_SCHEMA: Any

class SceneSchema(KNXPlatformSchema):
    PLATFORM_NAME: Any
    CONF_SCENE_NUMBER: str
    DEFAULT_NAME: str
    ENTITY_SCHEMA: Any

class SelectSchema(KNXPlatformSchema):
    PLATFORM_NAME: Any
    CONF_OPTION: str
    CONF_OPTIONS: str
    CONF_PAYLOAD: str
    CONF_PAYLOAD_LENGTH: str
    DEFAULT_NAME: str
    ENTITY_SCHEMA: Any

class SensorSchema(KNXPlatformSchema):
    PLATFORM_NAME: Any
    CONF_ALWAYS_CALLBACK: str
    CONF_STATE_ADDRESS: Any
    CONF_SYNC_STATE: Any
    DEFAULT_NAME: str
    ENTITY_SCHEMA: Any

class SwitchSchema(KNXPlatformSchema):
    PLATFORM_NAME: Any
    CONF_INVERT: Any
    CONF_STATE_ADDRESS: Any
    DEFAULT_NAME: str
    ENTITY_SCHEMA: Any

class WeatherSchema(KNXPlatformSchema):
    PLATFORM_NAME: Any
    CONF_SYNC_STATE: Any
    CONF_KNX_TEMPERATURE_ADDRESS: str
    CONF_KNX_BRIGHTNESS_SOUTH_ADDRESS: str
    CONF_KNX_BRIGHTNESS_EAST_ADDRESS: str
    CONF_KNX_BRIGHTNESS_WEST_ADDRESS: str
    CONF_KNX_BRIGHTNESS_NORTH_ADDRESS: str
    CONF_KNX_WIND_SPEED_ADDRESS: str
    CONF_KNX_WIND_BEARING_ADDRESS: str
    CONF_KNX_RAIN_ALARM_ADDRESS: str
    CONF_KNX_FROST_ALARM_ADDRESS: str
    CONF_KNX_WIND_ALARM_ADDRESS: str
    CONF_KNX_DAY_NIGHT_ADDRESS: str
    CONF_KNX_AIR_PRESSURE_ADDRESS: str
    CONF_KNX_HUMIDITY_ADDRESS: str
    DEFAULT_NAME: str
    ENTITY_SCHEMA: Any



from . import EsphomeEntity as EsphomeEntity, EsphomeEnumMapper as EsphomeEnumMapper, esphome_state_property as esphome_state_property, platform_async_setup_entry as platform_async_setup_entry
from aioesphomeapi import SensorInfo, SensorState, SensorStateClass, TextSensorInfo, TextSensorState
from homeassistant.components.sensor import DEVICE_CLASSES as DEVICE_CLASSES, DEVICE_CLASS_TIMESTAMP as DEVICE_CLASS_TIMESTAMP, STATE_CLASS_MEASUREMENT as STATE_CLASS_MEASUREMENT, SensorEntity as SensorEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.restore_state import RestoreEntity as RestoreEntity
from homeassistant.util import dt as dt
from typing import Any

ICON_SCHEMA: Any

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

_STATE_CLASSES: EsphomeEnumMapper[SensorStateClass, Union[str, None]]

class EsphomeSensor(EsphomeEntity[SensorInfo, SensorState], SensorEntity, RestoreEntity):
    _old_state: Union[float, None]
    _attr_last_reset: Any
    async def async_added_to_hass(self) -> None: ...
    def _on_state_update(self) -> None: ...
    @property
    def icon(self) -> Union[str, None]: ...
    @property
    def force_update(self) -> bool: ...
    def state(self) -> Union[str, None]: ...
    @property
    def unit_of_measurement(self) -> Union[str, None]: ...
    @property
    def device_class(self) -> Union[str, None]: ...
    @property
    def state_class(self) -> Union[str, None]: ...

class EsphomeTextSensor(EsphomeEntity[TextSensorInfo, TextSensorState], SensorEntity):
    @property
    def icon(self) -> str: ...
    def state(self) -> Union[str, None]: ...



from . import Stream as Stream
from .const import EXT_X_START as EXT_X_START, FORMAT_CONTENT_TYPE as FORMAT_CONTENT_TYPE, HLS_PROVIDER as HLS_PROVIDER, MAX_SEGMENTS as MAX_SEGMENTS, NUM_PLAYLIST_SEGMENTS as NUM_PLAYLIST_SEGMENTS
from .core import IdleTimer as IdleTimer, PROVIDERS as PROVIDERS, StreamOutput as StreamOutput, StreamView as StreamView
from .fmp4utils import get_codec_string as get_codec_string
from aiohttp import web
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback

def async_setup_hls(hass: HomeAssistant) -> str: ...

class HlsMasterPlaylistView(StreamView):
    url: str
    name: str
    cors_allowed: bool
    @staticmethod
    def render(track: StreamOutput) -> str: ...
    async def handle(self, request: web.Request, stream: Stream, sequence: str) -> web.Response: ...

class HlsPlaylistView(StreamView):
    url: str
    name: str
    cors_allowed: bool
    @staticmethod
    def render(track: StreamOutput) -> str: ...
    async def handle(self, request: web.Request, stream: Stream, sequence: str) -> web.Response: ...

class HlsInitView(StreamView):
    url: str
    name: str
    cors_allowed: bool
    async def handle(self, request: web.Request, stream: Stream, sequence: str) -> web.Response: ...

class HlsSegmentView(StreamView):
    url: str
    name: str
    cors_allowed: bool
    async def handle(self, request: web.Request, stream: Stream, sequence: str) -> web.Response: ...

class HlsStreamOutput(StreamOutput):
    def __init__(self, hass: HomeAssistant, idle_timer: IdleTimer) -> None: ...
    @property
    def name(self) -> str: ...



from typing import Final

CONF_BUFFER_SIZE: Final[str]
CONF_VALUE_ON: Final[str]
DEFAULT_BUFFER_SIZE: Final[int]
DEFAULT_NAME: Final[str]
DEFAULT_TIMEOUT: Final[int]
DEFAULT_SSL: Final[bool]
DEFAULT_VERIFY_SSL: Final[bool]



from . import websocket_api as websocket_api
from .const import DOMAIN as DOMAIN
from .data import async_get_manager as async_get_manager
from homeassistant.components import frontend as frontend
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers import discovery as discovery
from homeassistant.helpers.typing import ConfigType as ConfigType

async def is_configured(hass: HomeAssistant) -> bool: ...
async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool: ...



from .const import ATTR_METER_TYPE as ATTR_METER_TYPE, ATTR_VALUE as ATTR_VALUE, DATA_CLIENT as DATA_CLIENT, DOMAIN as DOMAIN, SERVICE_RESET_METER as SERVICE_RESET_METER
from .discovery import ZwaveDiscoveryInfo as ZwaveDiscoveryInfo
from .entity import ZWaveBaseEntity as ZWaveBaseEntity
from .helpers import get_device_id as get_device_id
from homeassistant.components.sensor import ATTR_LAST_RESET as ATTR_LAST_RESET, DEVICE_CLASS_BATTERY as DEVICE_CLASS_BATTERY, DEVICE_CLASS_ENERGY as DEVICE_CLASS_ENERGY, DEVICE_CLASS_ILLUMINANCE as DEVICE_CLASS_ILLUMINANCE, DEVICE_CLASS_POWER as DEVICE_CLASS_POWER, STATE_CLASS_MEASUREMENT as STATE_CLASS_MEASUREMENT, SensorEntity as SensorEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import DEVICE_CLASS_CURRENT as DEVICE_CLASS_CURRENT, DEVICE_CLASS_HUMIDITY as DEVICE_CLASS_HUMIDITY, DEVICE_CLASS_TEMPERATURE as DEVICE_CLASS_TEMPERATURE, DEVICE_CLASS_VOLTAGE as DEVICE_CLASS_VOLTAGE, TEMP_CELSIUS as TEMP_CELSIUS, TEMP_FAHRENHEIT as TEMP_FAHRENHEIT
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers import entity_platform as entity_platform
from homeassistant.helpers.dispatcher import async_dispatcher_connect as async_dispatcher_connect, async_dispatcher_send as async_dispatcher_send
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.restore_state import RestoreEntity as RestoreEntity
from homeassistant.util import dt as dt
from typing import Any
from zwave_js_server.client import Client as ZwaveClient
from zwave_js_server.model.node import Node as ZwaveNode

LOGGER: Any

async def async_setup_entry(hass: HomeAssistant, config_entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class ZwaveSensorBase(ZWaveBaseEntity, SensorEntity):
    _attr_name: Any
    _attr_device_class: Any
    _attr_state_class: Any
    def __init__(self, config_entry: ConfigEntry, client: ZwaveClient, info: ZwaveDiscoveryInfo) -> None: ...
    def _get_device_class(self) -> Union[str, None]: ...
    def _get_state_class(self) -> Union[str, None]: ...
    @property
    def force_update(self) -> bool: ...

class ZWaveStringSensor(ZwaveSensorBase):
    @property
    def state(self) -> Union[str, None]: ...
    @property
    def unit_of_measurement(self) -> Union[str, None]: ...

class ZWaveNumericSensor(ZwaveSensorBase):
    _attr_name: Any
    def __init__(self, config_entry: ConfigEntry, client: ZwaveClient, info: ZwaveDiscoveryInfo) -> None: ...
    @property
    def state(self) -> float: ...
    @property
    def unit_of_measurement(self) -> Union[str, None]: ...

class ZWaveMeterSensor(ZWaveNumericSensor, RestoreEntity):
    _attr_state_class: Any
    _attr_last_reset: Any
    def __init__(self, config_entry: ConfigEntry, client: ZwaveClient, info: ZwaveDiscoveryInfo) -> None: ...
    def async_update_last_reset(self, node: ZwaveNode, endpoint: int, meter_type: Union[int, None]) -> None: ...
    async def async_added_to_hass(self) -> None: ...
    async def async_reset_meter(self, meter_type: Union[int, None] = ..., value: Union[int, None] = ...) -> None: ...

class ZWaveListSensor(ZwaveSensorBase):
    _attr_name: Any
    def __init__(self, config_entry: ConfigEntry, client: ZwaveClient, info: ZwaveDiscoveryInfo) -> None: ...
    @property
    def state(self) -> Union[str, None]: ...
    @property
    def extra_state_attributes(self) -> Union[dict[str, str], None]: ...

class ZWaveConfigParameterSensor(ZwaveSensorBase):
    _primary_value: Any
    _attr_name: Any
    def __init__(self, config_entry: ConfigEntry, client: ZwaveClient, info: ZwaveDiscoveryInfo) -> None: ...
    @property
    def state(self) -> Union[str, None]: ...
    @property
    def extra_state_attributes(self) -> Union[dict[str, str], None]: ...

class ZWaveNodeStatusSensor(SensorEntity):
    _attr_should_poll: bool
    _attr_entity_registry_enabled_default: bool
    config_entry: Any
    client: Any
    node: Any
    _attr_name: Any
    _attr_unique_id: Any
    _attr_device_info: Any
    _attr_state: Any
    def __init__(self, config_entry: ConfigEntry, client: ZwaveClient, node: ZwaveNode) -> None: ...
    async def async_poll_value(self, _: bool) -> None: ...
    def _status_changed(self, _: dict) -> None: ...
    async def async_added_to_hass(self) -> None: ...
    @property
    def available(self) -> bool: ...



from . import EsphomeEntity as EsphomeEntity, esphome_state_property as esphome_state_property, platform_async_setup_entry as platform_async_setup_entry
from aioesphomeapi import SwitchInfo, SwitchState
from homeassistant.components.switch import SwitchEntity as SwitchEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from typing import Any

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class EsphomeSwitch(EsphomeEntity[SwitchInfo, SwitchState], SwitchEntity):
    @property
    def icon(self) -> str: ...
    @property
    def assumed_state(self) -> bool: ...
    def is_on(self) -> Union[bool, None]: ...
    async def async_turn_on(self, **kwargs: Any) -> None: ...
    async def async_turn_off(self, **kwargs: Any) -> None: ...



from .const import KEY_AUTHENTICATED as KEY_AUTHENTICATED, KEY_HASS_REFRESH_TOKEN_ID as KEY_HASS_REFRESH_TOKEN_ID, KEY_HASS_USER as KEY_HASS_USER
from aiohttp.web import Application as Application, Request as Request, StreamResponse as StreamResponse
from collections.abc import Callable as Callable
from datetime import timedelta
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from typing import Any, Final

_LOGGER: Any
DATA_API_PASSWORD: Final[str]
DATA_SIGN_SECRET: Final[str]
SIGN_QUERY_PARAM: Final[str]

def async_sign_path(hass: HomeAssistant, refresh_token_id: str, path: str, expiration: timedelta) -> str: ...
def setup_auth(hass: HomeAssistant, app: Application) -> None: ...



from . import ATTR_BRIGHTNESS as ATTR_BRIGHTNESS, ATTR_BRIGHTNESS_PCT as ATTR_BRIGHTNESS_PCT, ATTR_COLOR_MODE as ATTR_COLOR_MODE, ATTR_COLOR_NAME as ATTR_COLOR_NAME, ATTR_COLOR_TEMP as ATTR_COLOR_TEMP, ATTR_EFFECT as ATTR_EFFECT, ATTR_FLASH as ATTR_FLASH, ATTR_HS_COLOR as ATTR_HS_COLOR, ATTR_KELVIN as ATTR_KELVIN, ATTR_PROFILE as ATTR_PROFILE, ATTR_RGBWW_COLOR as ATTR_RGBWW_COLOR, ATTR_RGBW_COLOR as ATTR_RGBW_COLOR, ATTR_RGB_COLOR as ATTR_RGB_COLOR, ATTR_TRANSITION as ATTR_TRANSITION, ATTR_WHITE as ATTR_WHITE, ATTR_WHITE_VALUE as ATTR_WHITE_VALUE, ATTR_XY_COLOR as ATTR_XY_COLOR, COLOR_MODE_COLOR_TEMP as COLOR_MODE_COLOR_TEMP, COLOR_MODE_HS as COLOR_MODE_HS, COLOR_MODE_RGB as COLOR_MODE_RGB, COLOR_MODE_RGBW as COLOR_MODE_RGBW, COLOR_MODE_RGBWW as COLOR_MODE_RGBWW, COLOR_MODE_UNKNOWN as COLOR_MODE_UNKNOWN, COLOR_MODE_WHITE as COLOR_MODE_WHITE, COLOR_MODE_XY as COLOR_MODE_XY, DOMAIN as DOMAIN
from collections.abc import Iterable
from homeassistant.const import ATTR_ENTITY_ID as ATTR_ENTITY_ID, SERVICE_TURN_OFF as SERVICE_TURN_OFF, SERVICE_TURN_ON as SERVICE_TURN_ON, STATE_OFF as STATE_OFF, STATE_ON as STATE_ON
from homeassistant.core import Context as Context, HomeAssistant as HomeAssistant, State as State
from types import MappingProxyType
from typing import Any

_LOGGER: Any
VALID_STATES: Any
ATTR_GROUP: Any
COLOR_GROUP: Any
COLOR_MODE_TO_ATTRIBUTE: Any
DEPRECATED_GROUP: Any
DEPRECATION_WARNING: str

def _color_mode_same(cur_state: State, state: State) -> bool: ...
async def _async_reproduce_state(hass: HomeAssistant, state: State, *, context: Union[Context, None] = ..., reproduce_options: Union[dict[str, Any], None] = ...) -> None: ...
async def async_reproduce_states(hass: HomeAssistant, states: Iterable[State], *, context: Union[Context, None] = ..., reproduce_options: Union[dict[str, Any], None] = ...) -> None: ...
def check_attr_equal(attr1: MappingProxyType, attr2: MappingProxyType, attr_str: str) -> bool: ...



import pysnmp.hlapi.asyncio as SnmpEngine
from .const import DATA_CONFIG_ENTRY as DATA_CONFIG_ENTRY, DOMAIN as DOMAIN, SNMP as SNMP
from .utils import get_snmp_engine as get_snmp_engine
from brother import DictToObj as DictToObj
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import CONF_HOST as CONF_HOST, CONF_TYPE as CONF_TYPE
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.update_coordinator import DataUpdateCoordinator as DataUpdateCoordinator, UpdateFailed as UpdateFailed
from typing import Any

PLATFORMS: Any
SCAN_INTERVAL: Any
_LOGGER: Any

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...
async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...

class BrotherDataUpdateCoordinator(DataUpdateCoordinator):
    brother: Any
    def __init__(self, hass: HomeAssistant, host: str, kind: str, snmp_engine: SnmpEngine) -> None: ...
    async def _async_update_data(self) -> DictToObj: ...



from homeassistant.components.group import GroupIntegrationRegistry as GroupIntegrationRegistry
from homeassistant.const import STATE_IDLE as STATE_IDLE, STATE_OFF as STATE_OFF, STATE_ON as STATE_ON, STATE_PAUSED as STATE_PAUSED, STATE_PLAYING as STATE_PLAYING
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback

def async_describe_on_off_states(hass: HomeAssistant, registry: GroupIntegrationRegistry) -> None: ...



import homeassistant.util.dt as dt_util
from .trace import TraceElement as TraceElement, trace_append_element as trace_append_element, trace_path as trace_path, trace_path_get as trace_path_get, trace_stack_cv as trace_stack_cv, trace_stack_pop as trace_stack_pop, trace_stack_push as trace_stack_push, trace_stack_top as trace_stack_top
from collections.abc import Container, Generator
from datetime import timedelta
from homeassistant.components.device_automation import async_get_device_automation_platform as async_get_device_automation_platform
from homeassistant.components.sensor import DEVICE_CLASS_TIMESTAMP as DEVICE_CLASS_TIMESTAMP
from homeassistant.const import ATTR_DEVICE_CLASS as ATTR_DEVICE_CLASS, ATTR_GPS_ACCURACY as ATTR_GPS_ACCURACY, ATTR_LATITUDE as ATTR_LATITUDE, ATTR_LONGITUDE as ATTR_LONGITUDE, CONF_ABOVE as CONF_ABOVE, CONF_AFTER as CONF_AFTER, CONF_ATTRIBUTE as CONF_ATTRIBUTE, CONF_BEFORE as CONF_BEFORE, CONF_BELOW as CONF_BELOW, CONF_CONDITION as CONF_CONDITION, CONF_DEVICE_ID as CONF_DEVICE_ID, CONF_DOMAIN as CONF_DOMAIN, CONF_ENTITY_ID as CONF_ENTITY_ID, CONF_ID as CONF_ID, CONF_STATE as CONF_STATE, CONF_VALUE_TEMPLATE as CONF_VALUE_TEMPLATE, CONF_WEEKDAY as CONF_WEEKDAY, CONF_ZONE as CONF_ZONE, STATE_UNAVAILABLE as STATE_UNAVAILABLE, STATE_UNKNOWN as STATE_UNKNOWN, SUN_EVENT_SUNRISE as SUN_EVENT_SUNRISE, SUN_EVENT_SUNSET as SUN_EVENT_SUNSET, WEEKDAYS as WEEKDAYS
from homeassistant.core import HomeAssistant as HomeAssistant, State as State, callback as callback
from homeassistant.exceptions import ConditionError as ConditionError, ConditionErrorContainer as ConditionErrorContainer, ConditionErrorIndex as ConditionErrorIndex, ConditionErrorMessage as ConditionErrorMessage, HomeAssistantError as HomeAssistantError, TemplateError as TemplateError
from homeassistant.helpers.sun import get_astral_event_date as get_astral_event_date
from homeassistant.helpers.template import Template as Template
from homeassistant.helpers.typing import ConfigType as ConfigType, TemplateVarsType as TemplateVarsType
from homeassistant.util.async_ import run_callback_threadsafe as run_callback_threadsafe
from typing import Any, Callable

FROM_CONFIG_FORMAT: str
ASYNC_FROM_CONFIG_FORMAT: str
_LOGGER: Any
INPUT_ENTITY_ID: Any
ConditionCheckerType = Callable[[HomeAssistant, TemplateVarsType], bool]

def condition_trace_append(variables: TemplateVarsType, path: str) -> TraceElement: ...
def condition_trace_set_result(result: bool, **kwargs: Any) -> None: ...
def condition_trace_update_result(**kwargs: Any) -> None: ...
def trace_condition(variables: TemplateVarsType) -> Generator: ...
def trace_condition_function(condition: ConditionCheckerType) -> ConditionCheckerType: ...
async def async_from_config(hass: HomeAssistant, config: Union[ConfigType, Template], config_validation: bool = ...) -> ConditionCheckerType: ...
async def async_and_from_config(hass: HomeAssistant, config: ConfigType, config_validation: bool = ...) -> ConditionCheckerType: ...
async def async_or_from_config(hass: HomeAssistant, config: ConfigType, config_validation: bool = ...) -> ConditionCheckerType: ...
async def async_not_from_config(hass: HomeAssistant, config: ConfigType, config_validation: bool = ...) -> ConditionCheckerType: ...
def numeric_state(hass: HomeAssistant, entity: Union[None, str, State], below: Union[float, str, None] = ..., above: Union[float, str, None] = ..., value_template: Union[Template, None] = ..., variables: TemplateVarsType = ...) -> bool: ...
def async_numeric_state(hass: HomeAssistant, entity: Union[None, str, State], below: Union[float, str, None] = ..., above: Union[float, str, None] = ..., value_template: Union[Template, None] = ..., variables: TemplateVarsType = ..., attribute: Union[str, None] = ...) -> bool: ...
def async_numeric_state_from_config(config: ConfigType, config_validation: bool = ...) -> ConditionCheckerType: ...
def state(hass: HomeAssistant, entity: Union[None, str, State], req_state: Any, for_period: Union[timedelta, None] = ..., attribute: Union[str, None] = ...) -> bool: ...
def state_from_config(config: ConfigType, config_validation: bool = ...) -> ConditionCheckerType: ...
def sun(hass: HomeAssistant, before: Union[str, None] = ..., after: Union[str, None] = ..., before_offset: Union[timedelta, None] = ..., after_offset: Union[timedelta, None] = ...) -> bool: ...
def sun_from_config(config: ConfigType, config_validation: bool = ...) -> ConditionCheckerType: ...
def template(hass: HomeAssistant, value_template: Template, variables: TemplateVarsType = ...) -> bool: ...
def async_template(hass: HomeAssistant, value_template: Template, variables: TemplateVarsType = ..., trace_result: bool = ...) -> bool: ...
def async_template_from_config(config: ConfigType, config_validation: bool = ...) -> ConditionCheckerType: ...
def time(hass: HomeAssistant, before: Union[dt_util.dt.time, str, None] = ..., after: Union[dt_util.dt.time, str, None] = ..., weekday: Union[None, str, Container[str]] = ...) -> bool: ...
def time_from_config(config: ConfigType, config_validation: bool = ...) -> ConditionCheckerType: ...
def zone(hass: HomeAssistant, zone_ent: Union[None, str, State], entity: Union[None, str, State]) -> bool: ...
def zone_from_config(config: ConfigType, config_validation: bool = ...) -> ConditionCheckerType: ...
async def async_device_from_config(hass: HomeAssistant, config: ConfigType, config_validation: bool = ...) -> ConditionCheckerType: ...
async def async_trigger_from_config(hass: HomeAssistant, config: ConfigType, config_validation: bool = ...) -> ConditionCheckerType: ...
async def async_validate_condition_config(hass: HomeAssistant, config: Union[ConfigType, Template]) -> Union[ConfigType, Template]: ...
def async_extract_entities(config: Union[ConfigType, Template]) -> set[str]: ...
def async_extract_devices(config: Union[ConfigType, Template]) -> set[str]: ...



from homeassistant.core import HassJob as HassJob, HomeAssistant as HomeAssistant, callback as callback
from homeassistant.loader import bind_hass as bind_hass
from homeassistant.util.async_ import run_callback_threadsafe as run_callback_threadsafe
from homeassistant.util.logging import catch_log_exception as catch_log_exception
from typing import Any, Callable

_LOGGER: Any
DATA_DISPATCHER: str

def dispatcher_connect(hass: HomeAssistant, signal: str, target: Callable[..., None]) -> Callable[[], None]: ...
def async_dispatcher_connect(hass: HomeAssistant, signal: str, target: Callable[..., Any]) -> Callable[[], None]: ...
def dispatcher_send(hass: HomeAssistant, signal: str, *args: Any) -> None: ...
def async_dispatcher_send(hass: HomeAssistant, signal: str, *args: Any) -> None: ...



from . import get_hyperion_device_id as get_hyperion_device_id, get_hyperion_unique_id as get_hyperion_unique_id, listen_for_instance_updates as listen_for_instance_updates
from .const import CONF_INSTANCE_CLIENTS as CONF_INSTANCE_CLIENTS, DOMAIN as DOMAIN, HYPERION_MANUFACTURER_NAME as HYPERION_MANUFACTURER_NAME, HYPERION_MODEL_NAME as HYPERION_MODEL_NAME, NAME_SUFFIX_HYPERION_COMPONENT_SWITCH as NAME_SUFFIX_HYPERION_COMPONENT_SWITCH, SIGNAL_ENTITY_REMOVE as SIGNAL_ENTITY_REMOVE, TYPE_HYPERION_COMPONENT_SWITCH_BASE as TYPE_HYPERION_COMPONENT_SWITCH_BASE
from homeassistant.components.switch import SwitchEntity as SwitchEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.dispatcher import async_dispatcher_connect as async_dispatcher_connect, async_dispatcher_send as async_dispatcher_send
from homeassistant.helpers.entity import DeviceInfo as DeviceInfo
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.util import slugify as slugify
from hyperion import client as client
from typing import Any

COMPONENT_SWITCHES: Any

def _component_to_unique_id(server_id: str, component: str, instance_num: int) -> str: ...
def _component_to_switch_name(component: str, instance_name: str) -> str: ...
async def async_setup_entry(hass: HomeAssistant, config_entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> bool: ...

class HyperionComponentSwitch(SwitchEntity):
    _unique_id: Any
    _device_id: Any
    _name: Any
    _instance_name: Any
    _component_name: Any
    _client: Any
    _client_callbacks: Any
    def __init__(self, server_id: str, instance_num: int, instance_name: str, component_name: str, hyperion_client: client.HyperionClient) -> None: ...
    @property
    def should_poll(self) -> bool: ...
    @property
    def entity_registry_enabled_default(self) -> bool: ...
    @property
    def unique_id(self) -> str: ...
    @property
    def name(self) -> str: ...
    @property
    def is_on(self) -> bool: ...
    @property
    def available(self) -> bool: ...
    @property
    def device_info(self) -> DeviceInfo: ...
    async def _async_send_set_component(self, value: bool) -> None: ...
    async def async_turn_on(self, **kwargs: Any) -> None: ...
    async def async_turn_off(self, **kwargs: Any) -> None: ...
    def _update_components(self, _: Union[dict[str, Any], None] = ...) -> None: ...
    async def async_added_to_hass(self) -> None: ...
    async def async_will_remove_from_hass(self) -> None: ...



from .const import DATA_DISCOVERY as DATA_DISCOVERY, DOMAIN as DOMAIN
from .utils import async_discover_devices as async_discover_devices
from homeassistant import config_entries as config_entries
from homeassistant.data_entry_flow import FlowResult as FlowResult
from homeassistant.helpers.typing import ConfigType as ConfigType
from typing import Any

class SwitcherFlowHandler(config_entries.ConfigFlow):
    async def async_step_import(self, import_config: ConfigType) -> FlowResult: ...
    async def async_step_user(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    async def async_step_confirm(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...



from . import get_entity_ids as get_entity_ids
from collections.abc import Iterable
from homeassistant.core import Context as Context, HomeAssistant as HomeAssistant, State as State
from homeassistant.helpers.state import async_reproduce_state as async_reproduce_state
from typing import Any

async def async_reproduce_states(hass: HomeAssistant, states: Iterable[State], *, context: Union[Context, None] = ..., reproduce_options: Union[dict[str, Any], None] = ...) -> None: ...



import yaml
from .objects import Input as Input, NodeListClass as NodeListClass
from typing import Any

def dump(_dict: dict) -> str: ...
def save_yaml(path: str, data: dict) -> None: ...
def represent_odict(dumper, tag, mapping, flow_style: Any | None = ...) -> yaml.MappingNode: ...



from typing import Any

_LOGGER: Any

def is_virtual_env() -> bool: ...
def is_docker_env() -> bool: ...
def is_installed(package: str) -> bool: ...
def install_package(package: str, upgrade: bool = ..., target: Union[str, None] = ..., constraints: Union[str, None] = ..., find_links: Union[str, None] = ..., timeout: Union[int, None] = ..., no_cache_dir: Union[bool, None] = ...) -> bool: ...
async def async_get_user_site(deps_dir: str) -> str: ...



import aiohttp
from homeassistant.const import CONF_DOMAIN as CONF_DOMAIN, CONF_PASSWORD as CONF_PASSWORD, CONF_TIMEOUT as CONF_TIMEOUT, CONF_USERNAME as CONF_USERNAME
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.aiohttp_client import SERVER_SOFTWARE as SERVER_SOFTWARE
from homeassistant.helpers.typing import ConfigType as ConfigType
from typing import Any

_LOGGER: Any
DOMAIN: str
EMAIL: str
INTERVAL: Any
DEFAULT_TIMEOUT: int
NO_IP_ERRORS: Any
UPDATE_URL: str
HA_USER_AGENT: Any
CONFIG_SCHEMA: Any

async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool: ...
async def _update_no_ip(hass: HomeAssistant, session: aiohttp.ClientSession, domain: str, auth_str: bytes, timeout: int) -> bool: ...



import datetime
from homeassistant.components.sensor import PLATFORM_SCHEMA as PLATFORM_SCHEMA, SensorEntity as SensorEntity
from homeassistant.const import CONF_RESOURCES as CONF_RESOURCES, CONF_SCAN_INTERVAL as CONF_SCAN_INTERVAL, CONF_TYPE as CONF_TYPE, DATA_GIBIBYTES as DATA_GIBIBYTES, DATA_MEBIBYTES as DATA_MEBIBYTES, DATA_RATE_MEGABYTES_PER_SECOND as DATA_RATE_MEGABYTES_PER_SECOND, DEVICE_CLASS_TEMPERATURE as DEVICE_CLASS_TEMPERATURE, DEVICE_CLASS_TIMESTAMP as DEVICE_CLASS_TIMESTAMP, EVENT_HOMEASSISTANT_STOP as EVENT_HOMEASSISTANT_STOP, PERCENTAGE as PERCENTAGE, STATE_OFF as STATE_OFF, STATE_ON as STATE_ON, TEMP_CELSIUS as TEMP_CELSIUS
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.dispatcher import async_dispatcher_connect as async_dispatcher_connect, async_dispatcher_send as async_dispatcher_send
from homeassistant.helpers.entity_component import DEFAULT_SCAN_INTERVAL as DEFAULT_SCAN_INTERVAL
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.event import async_track_time_interval as async_track_time_interval
from homeassistant.helpers.typing import ConfigType as ConfigType
from homeassistant.util import slugify as slugify
from typing import Any

_LOGGER: Any
CONF_ARG: str
CPU_ICON: str
SENSOR_TYPE_NAME: int
SENSOR_TYPE_UOM: int
SENSOR_TYPE_ICON: int
SENSOR_TYPE_DEVICE_CLASS: int
SENSOR_TYPE_MANDATORY_ARG: int
SIGNAL_SYSTEMMONITOR_UPDATE: str
SENSOR_TYPES: dict[str, tuple[str, Union[str, None], Union[str, None], Union[str, None], bool]]

def check_required_arg(value: Any) -> Any: ...

IO_COUNTER: Any
IF_ADDRS_FAMILY: Any
CPU_SENSOR_PREFIXES: Any

class SensorData:
    argument: Any
    state: Union[str, None]
    value: Union[Any, None]
    update_time: Union[datetime.datetime, None]
    last_exception: Union[BaseException, None]

async def async_setup_platform(hass: HomeAssistant, config: ConfigType, async_add_entities: AddEntitiesCallback, discovery_info: Union[Any, None] = ...) -> None: ...
async def async_setup_sensor_registry_updates(hass: HomeAssistant, sensor_registry: dict[tuple[str, str], SensorData], scan_interval: datetime.timedelta) -> None: ...

class SystemMonitorSensor(SensorEntity):
    _type: Any
    _name: Any
    _unique_id: Any
    _sensor_registry: Any
    _argument: Any
    def __init__(self, sensor_registry: dict[tuple[str, str], SensorData], sensor_type: str, argument: str = ...) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def unique_id(self) -> str: ...
    @property
    def device_class(self) -> Union[str, None]: ...
    @property
    def icon(self) -> Union[str, None]: ...
    @property
    def state(self) -> Union[str, None]: ...
    @property
    def unit_of_measurement(self) -> Union[str, None]: ...
    @property
    def available(self) -> bool: ...
    @property
    def should_poll(self) -> bool: ...
    @property
    def sensor_type(self) -> list: ...
    @property
    def data(self) -> SensorData: ...
    async def async_added_to_hass(self) -> None: ...

def _update(type_: str, data: SensorData) -> tuple[Union[str, None], Union[str, None], Union[datetime.datetime, None]]: ...
def _disk_usage(path: str) -> Any: ...
def _swap_memory() -> Any: ...
def _virtual_memory() -> Any: ...
def _net_io_counters() -> Any: ...
def _net_if_addrs() -> Any: ...
def _getloadavg() -> tuple[float, float, float]: ...
def _read_cpu_temperature() -> Union[float, None]: ...



from .const import ATTRIBUTION as ATTRIBUTION, ATTR_ACCESS_TOKEN as ATTR_ACCESS_TOKEN, ATTR_LAST_SAVED_AT as ATTR_LAST_SAVED_AT, ATTR_REFRESH_TOKEN as ATTR_REFRESH_TOKEN, BATTERY_LEVELS as BATTERY_LEVELS, CONF_CLOCK_FORMAT as CONF_CLOCK_FORMAT, CONF_MONITORED_RESOURCES as CONF_MONITORED_RESOURCES, DEFAULT_CLOCK_FORMAT as DEFAULT_CLOCK_FORMAT, DEFAULT_CONFIG as DEFAULT_CONFIG, FITBIT_AUTH_CALLBACK_PATH as FITBIT_AUTH_CALLBACK_PATH, FITBIT_AUTH_START as FITBIT_AUTH_START, FITBIT_CONFIG_FILE as FITBIT_CONFIG_FILE, FITBIT_DEFAULT_RESOURCES as FITBIT_DEFAULT_RESOURCES, FITBIT_MEASUREMENTS as FITBIT_MEASUREMENTS, FITBIT_RESOURCES_LIST as FITBIT_RESOURCES_LIST
from aiohttp.web import Request as Request
from fitbit import Fitbit
from fitbit.api import FitbitOauth2Client
from homeassistant.components.http import HomeAssistantView as HomeAssistantView
from homeassistant.components.sensor import SensorEntity as SensorEntity
from homeassistant.const import ATTR_ATTRIBUTION as ATTR_ATTRIBUTION, CONF_CLIENT_ID as CONF_CLIENT_ID, CONF_CLIENT_SECRET as CONF_CLIENT_SECRET, CONF_UNIT_SYSTEM as CONF_UNIT_SYSTEM
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.icon import icon_for_battery_level as icon_for_battery_level
from homeassistant.helpers.network import get_url as get_url
from homeassistant.helpers.typing import ConfigType as ConfigType, DiscoveryInfoType as DiscoveryInfoType
from homeassistant.util.json import load_json as load_json, save_json as save_json
from typing import Any, Final

_LOGGER: Final[Any]
_CONFIGURING: dict[str, str]
SCAN_INTERVAL: Final[Any]
PLATFORM_SCHEMA: Final[Any]

def request_app_setup(hass: HomeAssistant, config: ConfigType, add_entities: AddEntitiesCallback, config_path: str, discovery_info: Union[DiscoveryInfoType, None] = ...) -> None: ...
def request_oauth_completion(hass: HomeAssistant) -> None: ...
def setup_platform(hass: HomeAssistant, config: ConfigType, add_entities: AddEntitiesCallback, discovery_info: Union[DiscoveryInfoType, None] = ...) -> None: ...

class FitbitAuthCallbackView(HomeAssistantView):
    requires_auth: bool
    url: Any
    name: str
    config: Any
    add_entities: Any
    oauth: Any
    def __init__(self, config: ConfigType, add_entities: AddEntitiesCallback, oauth: FitbitOauth2Client) -> None: ...
    async def get(self, request: Request) -> str: ...

class FitbitSensor(SensorEntity):
    client: Any
    config_path: Any
    resource_type: Any
    is_metric: Any
    clock_format: Any
    extra: Any
    _name: Any
    _unit_of_measurement: Any
    _state: Any
    def __init__(self, client: Fitbit, config_path: str, resource_type: str, is_metric: bool, clock_format: str, extra: Union[dict[str, str], None] = ...) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def state(self) -> Union[str, None]: ...
    @property
    def unit_of_measurement(self) -> Union[str, None]: ...
    @property
    def icon(self) -> str: ...
    @property
    def extra_state_attributes(self) -> dict[str, Union[str, None]]: ...
    def update(self) -> None: ...



from . import AirVisualEntity as AirVisualEntity
from .const import CONF_CITY as CONF_CITY, CONF_COUNTRY as CONF_COUNTRY, CONF_INTEGRATION_TYPE as CONF_INTEGRATION_TYPE, DATA_COORDINATOR as DATA_COORDINATOR, DOMAIN as DOMAIN, INTEGRATION_TYPE_GEOGRAPHY_COORDS as INTEGRATION_TYPE_GEOGRAPHY_COORDS, INTEGRATION_TYPE_GEOGRAPHY_NAME as INTEGRATION_TYPE_GEOGRAPHY_NAME
from homeassistant.components.sensor import SensorEntity as SensorEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import ATTR_LATITUDE as ATTR_LATITUDE, ATTR_LONGITUDE as ATTR_LONGITUDE, ATTR_STATE as ATTR_STATE, CONCENTRATION_MICROGRAMS_PER_CUBIC_METER as CONCENTRATION_MICROGRAMS_PER_CUBIC_METER, CONCENTRATION_PARTS_PER_BILLION as CONCENTRATION_PARTS_PER_BILLION, CONCENTRATION_PARTS_PER_MILLION as CONCENTRATION_PARTS_PER_MILLION, CONF_LATITUDE as CONF_LATITUDE, CONF_LONGITUDE as CONF_LONGITUDE, CONF_SHOW_ON_MAP as CONF_SHOW_ON_MAP, CONF_STATE as CONF_STATE, DEVICE_CLASS_BATTERY as DEVICE_CLASS_BATTERY, DEVICE_CLASS_CO2 as DEVICE_CLASS_CO2, DEVICE_CLASS_HUMIDITY as DEVICE_CLASS_HUMIDITY, DEVICE_CLASS_TEMPERATURE as DEVICE_CLASS_TEMPERATURE, PERCENTAGE as PERCENTAGE, TEMP_CELSIUS as TEMP_CELSIUS
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.entity import DeviceInfo as DeviceInfo
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.update_coordinator import DataUpdateCoordinator as DataUpdateCoordinator
from typing import Any

ATTR_CITY: str
ATTR_COUNTRY: str
ATTR_POLLUTANT_SYMBOL: str
ATTR_POLLUTANT_UNIT: str
ATTR_REGION: str
DEVICE_CLASS_POLLUTANT_LABEL: str
DEVICE_CLASS_POLLUTANT_LEVEL: str
SENSOR_KIND_AQI: str
SENSOR_KIND_BATTERY_LEVEL: str
SENSOR_KIND_CO2: str
SENSOR_KIND_HUMIDITY: str
SENSOR_KIND_LEVEL: str
SENSOR_KIND_PM_0_1: str
SENSOR_KIND_PM_1_0: str
SENSOR_KIND_PM_2_5: str
SENSOR_KIND_POLLUTANT: str
SENSOR_KIND_SENSOR_LIFE: str
SENSOR_KIND_TEMPERATURE: str
SENSOR_KIND_VOC: str
GEOGRAPHY_SENSORS: Any
GEOGRAPHY_SENSOR_LOCALES: Any
NODE_PRO_SENSORS: Any
STATE_POLLUTANT_LABEL_CO: str
STATE_POLLUTANT_LABEL_N2: str
STATE_POLLUTANT_LABEL_O3: str
STATE_POLLUTANT_LABEL_P1: str
STATE_POLLUTANT_LABEL_P2: str
STATE_POLLUTANT_LABEL_S2: str
STATE_POLLUTANT_LEVEL_GOOD: str
STATE_POLLUTANT_LEVEL_MODERATE: str
STATE_POLLUTANT_LEVEL_UNHEALTHY_SENSITIVE: str
STATE_POLLUTANT_LEVEL_UNHEALTHY: str
STATE_POLLUTANT_LEVEL_VERY_UNHEALTHY: str
STATE_POLLUTANT_LEVEL_HAZARDOUS: str
POLLUTANT_LEVELS: Any
POLLUTANT_UNITS: Any

async def async_setup_entry(hass: HomeAssistant, config_entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class AirVisualGeographySensor(AirVisualEntity, SensorEntity):
    _attr_device_class: Any
    _attr_icon: Any
    _attr_name: Any
    _attr_unique_id: Any
    _attr_unit_of_measurement: Any
    _config_entry: Any
    _kind: Any
    _locale: Any
    def __init__(self, coordinator: DataUpdateCoordinator, config_entry: ConfigEntry, kind: str, name: str, icon: str, unit: Union[str, None], locale: str) -> None: ...
    @property
    def available(self) -> bool: ...
    _attr_state: Any
    def update_from_latest_data(self) -> None: ...

class AirVisualNodeProSensor(AirVisualEntity, SensorEntity):
    _attr_device_class: Any
    _attr_icon: Any
    _attr_name: Any
    _attr_unique_id: Any
    _attr_unit_of_measurement: Any
    _kind: Any
    def __init__(self, coordinator: DataUpdateCoordinator, kind: str, name: str, device_class: Union[str, None], icon: Union[str, None], unit: str) -> None: ...
    @property
    def device_info(self) -> DeviceInfo: ...
    _attr_state: Any
    def update_from_latest_data(self) -> None: ...



from .const import BPUP_STOP as BPUP_STOP, BPUP_SUBS as BPUP_SUBS, BRIDGE_MAKE as BRIDGE_MAKE, DOMAIN as DOMAIN, HUB as HUB
from .utils import BondHub as BondHub
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import CONF_ACCESS_TOKEN as CONF_ACCESS_TOKEN, CONF_HOST as CONF_HOST, EVENT_HOMEASSISTANT_STOP as EVENT_HOMEASSISTANT_STOP
from homeassistant.core import Event as Event, HomeAssistant as HomeAssistant, callback as callback
from homeassistant.exceptions import ConfigEntryNotReady as ConfigEntryNotReady
from homeassistant.helpers import device_registry as dr
from homeassistant.helpers.aiohttp_client import async_get_clientsession as async_get_clientsession
from homeassistant.helpers.entity import SLOW_UPDATE_WARNING as SLOW_UPDATE_WARNING
from typing import Any

PLATFORMS: Any
_API_TIMEOUT: Any
_STOP_CANCEL: str

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...
async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...
def _async_remove_old_device_identifiers(config_entry_id: str, device_registry: dr.DeviceRegistry, hub: BondHub) -> None: ...



from .const import ColorTempModes as ColorTempModes, DOMAIN as DOMAIN, KNX_ADDRESS as KNX_ADDRESS
from .knx_entity import KnxEntity as KnxEntity
from .schema import LightSchema as LightSchema
from homeassistant.components.light import ATTR_BRIGHTNESS as ATTR_BRIGHTNESS, ATTR_COLOR_TEMP as ATTR_COLOR_TEMP, ATTR_HS_COLOR as ATTR_HS_COLOR, ATTR_RGBW_COLOR as ATTR_RGBW_COLOR, ATTR_RGB_COLOR as ATTR_RGB_COLOR, ATTR_XY_COLOR as ATTR_XY_COLOR, COLOR_MODE_BRIGHTNESS as COLOR_MODE_BRIGHTNESS, COLOR_MODE_COLOR_TEMP as COLOR_MODE_COLOR_TEMP, COLOR_MODE_HS as COLOR_MODE_HS, COLOR_MODE_ONOFF as COLOR_MODE_ONOFF, COLOR_MODE_RGB as COLOR_MODE_RGB, COLOR_MODE_RGBW as COLOR_MODE_RGBW, COLOR_MODE_XY as COLOR_MODE_XY, LightEntity as LightEntity
from homeassistant.const import CONF_NAME as CONF_NAME
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.typing import ConfigType as ConfigType, DiscoveryInfoType as DiscoveryInfoType
from typing import Any
from xknx import XKNX as XKNX
from xknx.devices.light import Light as XknxLight

async def async_setup_platform(hass: HomeAssistant, config: ConfigType, async_add_entities: AddEntitiesCallback, discovery_info: Union[DiscoveryInfoType, None] = ...) -> None: ...
def _async_migrate_unique_id(hass: HomeAssistant, platform_config: list[ConfigType]) -> None: ...
def _create_light(xknx: XKNX, config: ConfigType) -> XknxLight: ...

class KNXLight(KnxEntity, LightEntity):
    _device: XknxLight
    _max_kelvin: Any
    _min_kelvin: Any
    _attr_max_mireds: Any
    _attr_min_mireds: Any
    _attr_unique_id: Any
    def __init__(self, xknx: XKNX, config: ConfigType) -> None: ...
    def _device_unique_id(self) -> str: ...
    @property
    def is_on(self) -> bool: ...
    @property
    def brightness(self) -> Union[int, None]: ...
    @property
    def rgb_color(self) -> Union[tuple[int, int, int], None]: ...
    @property
    def rgbw_color(self) -> Union[tuple[int, int, int, int], None]: ...
    @property
    def hs_color(self) -> Union[tuple[float, float], None]: ...
    @property
    def xy_color(self) -> Union[tuple[float, float], None]: ...
    @property
    def color_temp(self) -> Union[int, None]: ...
    @property
    def color_mode(self) -> Union[str, None]: ...
    @property
    def supported_color_modes(self) -> Union[set, None]: ...
    async def async_turn_on(self, **kwargs: Any) -> None: ...
    async def async_turn_off(self, **kwargs: Any) -> None: ...



from .models import HaAsyncServiceBrowser as HaAsyncServiceBrowser, HaAsyncZeroconf as HaAsyncZeroconf, HaZeroconf as HaZeroconf
from .usage import install_multiple_zeroconf_catcher as install_multiple_zeroconf_catcher
from collections.abc import Coroutine
from homeassistant import config_entries as config_entries
from homeassistant.components import network as network
from homeassistant.components.network import async_get_source_ip as async_get_source_ip
from homeassistant.components.network.models import Adapter as Adapter
from homeassistant.const import EVENT_HOMEASSISTANT_START as EVENT_HOMEASSISTANT_START, EVENT_HOMEASSISTANT_STARTED as EVENT_HOMEASSISTANT_STARTED, EVENT_HOMEASSISTANT_STOP as EVENT_HOMEASSISTANT_STOP, __version__ as __version__
from homeassistant.core import Event as Event, HomeAssistant as HomeAssistant, callback as callback
from homeassistant.data_entry_flow import FlowResult as FlowResult
from homeassistant.helpers.network import NoURLAvailableError as NoURLAvailableError, get_url as get_url
from homeassistant.loader import async_get_homekit as async_get_homekit, async_get_zeroconf as async_get_zeroconf, bind_hass as bind_hass
from typing import Any, TypedDict
from zeroconf import ServiceStateChange
from zeroconf.asyncio import AsyncServiceInfo

_LOGGER: Any
DOMAIN: str
ZEROCONF_TYPE: str
HOMEKIT_TYPES: Any
CONF_DEFAULT_INTERFACE: str
CONF_IPV6: str
DEFAULT_DEFAULT_INTERFACE: bool
DEFAULT_IPV6: bool
HOMEKIT_PAIRED_STATUS_FLAG: str
HOMEKIT_MODEL: str
MDNS_TARGET_IP: str
MAX_PROPERTY_VALUE_LEN: int
MAX_NAME_LEN: int
CONFIG_SCHEMA: Any

class HaServiceInfo(TypedDict):
    host: str
    port: Union[int, None]
    hostname: str
    type: str
    name: str
    properties: dict[str, Any]

class ZeroconfFlow(TypedDict):
    domain: str
    context: dict[str, Any]
    data: HaServiceInfo

async def async_get_instance(hass: HomeAssistant) -> HaZeroconf: ...
async def async_get_async_instance(hass: HomeAssistant) -> HaAsyncZeroconf: ...
async def _async_get_instance(hass: HomeAssistant, **zcargs: Any) -> HaAsyncZeroconf: ...
def _async_use_default_interface(adapters: list[Adapter]) -> bool: ...
async def async_setup(hass: HomeAssistant, config: dict) -> bool: ...
def _get_announced_addresses(adapters: list[Adapter], first_ip: Union[bytes, None] = ...) -> list[bytes]: ...
async def _async_register_hass_zc_service(hass: HomeAssistant, aio_zc: HaAsyncZeroconf, uuid: str) -> None: ...

class FlowDispatcher:
    hass: Any
    pending_flows: Any
    started: bool
    def __init__(self, hass: HomeAssistant) -> None: ...
    def async_start(self) -> None: ...
    def _async_process_pending_flows(self) -> None: ...
    def async_create(self, flow: ZeroconfFlow) -> None: ...
    def _init_flow(self, flow: ZeroconfFlow) -> Coroutine[None, None, FlowResult]: ...

class ZeroconfDiscovery:
    hass: Any
    zeroconf: Any
    zeroconf_types: Any
    homekit_models: Any
    ipv6: Any
    flow_dispatcher: Any
    async_service_browser: Any
    def __init__(self, hass: HomeAssistant, zeroconf: HaZeroconf, zeroconf_types: dict[str, list[dict[str, str]]], homekit_models: dict[str, str], ipv6: bool) -> None: ...
    async def async_setup(self) -> None: ...
    async def async_stop(self) -> None: ...
    def async_start(self) -> None: ...
    def async_service_update(self, zeroconf: HaZeroconf, service_type: str, name: str, state_change: ServiceStateChange) -> None: ...
    async def _process_service_update(self, zeroconf: HaZeroconf, service_type: str, name: str) -> None: ...

def handle_homekit(hass: HomeAssistant, homekit_models: dict[str, str], info: HaServiceInfo) -> Union[ZeroconfFlow, None]: ...
def info_from_service(service: AsyncServiceInfo) -> Union[HaServiceInfo, None]: ...
def _suppress_invalid_properties(properties: dict) -> None: ...
def _truncate_location_name_to_valid(location_name: str) -> str: ...



from collections.abc import Sequence
from homeassistant import runner as runner
from homeassistant.bootstrap import async_mount_local_lib_path as async_mount_local_lib_path
from homeassistant.config import get_default_config_dir as get_default_config_dir
from homeassistant.requirements import pip_kwargs as pip_kwargs
from homeassistant.util.package import install_package as install_package, is_installed as is_installed, is_virtual_env as is_virtual_env

def run(args: list) -> int: ...
def extract_config_dir(args: Union[Sequence[str], None] = ...) -> str: ...



from ipaddress import IPv4Address, IPv6Address
from typing import Any

LOOPBACK_NETWORKS: Any
PRIVATE_NETWORKS: Any
LINK_LOCAL_NETWORK: Any

def is_loopback(address: Union[IPv4Address, IPv6Address]) -> bool: ...
def is_private(address: Union[IPv4Address, IPv6Address]) -> bool: ...
def is_link_local(address: Union[IPv4Address, IPv6Address]) -> bool: ...
def is_local(address: Union[IPv4Address, IPv6Address]) -> bool: ...
def is_invalid(address: Union[IPv4Address, IPv6Address]) -> bool: ...
def is_ip_address(address: str) -> bool: ...
def normalize_url(address: str) -> str: ...



from . import NAMDataUpdateCoordinator as NAMDataUpdateCoordinator
from .const import ATTR_UPTIME as ATTR_UPTIME, DOMAIN as DOMAIN, MIGRATION_SENSORS as MIGRATION_SENSORS, SENSORS as SENSORS
from homeassistant.components.sensor import SensorEntity as SensorEntity, SensorEntityDescription as SensorEntityDescription
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers import entity_registry as entity_registry
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.typing import StateType as StateType
from homeassistant.helpers.update_coordinator import CoordinatorEntity as CoordinatorEntity
from homeassistant.util.dt import utcnow as utcnow
from typing import Any

PARALLEL_UPDATES: int
_LOGGER: Any

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class NAMSensor(CoordinatorEntity, SensorEntity):
    coordinator: NAMDataUpdateCoordinator
    _attr_device_info: Any
    _attr_unique_id: Any
    entity_description: Any
    def __init__(self, coordinator: NAMDataUpdateCoordinator, description: SensorEntityDescription) -> None: ...
    @property
    def state(self) -> StateType: ...
    @property
    def available(self) -> bool: ...

class NAMSensorUptime(NAMSensor):
    @property
    def state(self) -> str: ...



from .const import DOMAIN as DOMAIN
from homeassistant.config_entries import ConfigFlow as ConfigFlow
from homeassistant.data_entry_flow import FlowResult as FlowResult
from typing import Any

class SimpleConfigFlow(ConfigFlow):
    VERSION: int
    async def async_step_user(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...



from .const import CONF_TRACKED_ASSET_PAIRS as CONF_TRACKED_ASSET_PAIRS, DEFAULT_SCAN_INTERVAL as DEFAULT_SCAN_INTERVAL, DEFAULT_TRACKED_ASSET_PAIR as DEFAULT_TRACKED_ASSET_PAIR, DISPATCH_CONFIG_UPDATED as DISPATCH_CONFIG_UPDATED, DOMAIN as DOMAIN, KrakenResponse as KrakenResponse
from .utils import get_tradable_asset_pairs as get_tradable_asset_pairs
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import CONF_SCAN_INTERVAL as CONF_SCAN_INTERVAL
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.dispatcher import async_dispatcher_send as async_dispatcher_send
from homeassistant.helpers.update_coordinator import DataUpdateCoordinator as DataUpdateCoordinator, UpdateFailed as UpdateFailed
from typing import Any

CALL_RATE_LIMIT_SLEEP: int
PLATFORMS: Any
_LOGGER: Any

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...
async def async_unload_entry(hass: HomeAssistant, config_entry: ConfigEntry) -> bool: ...

class KrakenData:
    _hass: Any
    _config_entry: Any
    _api: Any
    tradable_asset_pairs: Any
    coordinator: Any
    def __init__(self, hass: HomeAssistant, config_entry: ConfigEntry) -> None: ...
    async def async_update(self) -> Union[KrakenResponse, None]: ...
    def _get_kraken_data(self) -> KrakenResponse: ...
    async def _async_refresh_tradable_asset_pairs(self) -> None: ...
    async def async_setup(self) -> None: ...
    def _get_websocket_name_asset_pairs(self) -> str: ...
    def set_update_interval(self, update_interval: int) -> None: ...

async def async_options_updated(hass: HomeAssistant, config_entry: ConfigEntry) -> None: ...



import voluptuous as vol
from .const import CONF_DEVICE_TOKEN as CONF_DEVICE_TOKEN, CONF_VOLUMES as CONF_VOLUMES, DEFAULT_PORT as DEFAULT_PORT, DEFAULT_PORT_SSL as DEFAULT_PORT_SSL, DEFAULT_SCAN_INTERVAL as DEFAULT_SCAN_INTERVAL, DEFAULT_TIMEOUT as DEFAULT_TIMEOUT, DEFAULT_USE_SSL as DEFAULT_USE_SSL, DEFAULT_VERIFY_SSL as DEFAULT_VERIFY_SSL, DOMAIN as DOMAIN, EXCEPTION_DETAILS as EXCEPTION_DETAILS
from homeassistant import exceptions as exceptions
from homeassistant.components import ssdp as ssdp
from homeassistant.config_entries import ConfigEntry as ConfigEntry, ConfigFlow as ConfigFlow, OptionsFlow as OptionsFlow
from homeassistant.const import CONF_DISKS as CONF_DISKS, CONF_HOST as CONF_HOST, CONF_MAC as CONF_MAC, CONF_NAME as CONF_NAME, CONF_PASSWORD as CONF_PASSWORD, CONF_PORT as CONF_PORT, CONF_SCAN_INTERVAL as CONF_SCAN_INTERVAL, CONF_SSL as CONF_SSL, CONF_TIMEOUT as CONF_TIMEOUT, CONF_USERNAME as CONF_USERNAME, CONF_VERIFY_SSL as CONF_VERIFY_SSL
from homeassistant.core import callback as callback
from homeassistant.data_entry_flow import FlowResult as FlowResult
from homeassistant.helpers.typing import DiscoveryInfoType as DiscoveryInfoType
from synology_dsm import SynologyDSM
from typing import Any

_LOGGER: Any
CONF_OTP_CODE: str

def _discovery_schema_with_defaults(discovery_info: DiscoveryInfoType) -> vol.Schema: ...
def _reauth_schema_with_defaults(user_input: dict[str, Any]) -> vol.Schema: ...
def _user_schema_with_defaults(user_input: dict[str, Any]) -> vol.Schema: ...
def _ordered_shared_schema(schema_input: dict[str, Any]) -> dict[Union[vol.Required, vol.Optional], Any]: ...

class SynologyDSMFlowHandler(ConfigFlow):
    VERSION: int
    @staticmethod
    def async_get_options_flow(config_entry: ConfigEntry) -> SynologyDSMOptionsFlowHandler: ...
    saved_user_input: Any
    discovered_conf: Any
    reauth_conf: Any
    reauth_reason: Any
    def __init__(self) -> None: ...
    async def _show_setup_form(self, user_input: Union[dict[str, Any], None] = ..., errors: Union[dict[str, str], None] = ...) -> FlowResult: ...
    async def async_step_user(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    async def async_step_ssdp(self, discovery_info: DiscoveryInfoType) -> FlowResult: ...
    async def async_step_reauth(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    async def async_step_link(self, user_input: dict[str, Any]) -> FlowResult: ...
    async def async_step_2sa(self, user_input: dict[str, Any], errors: Union[dict[str, str], None] = ...) -> FlowResult: ...
    def _mac_already_configured(self, mac: str) -> bool: ...

class SynologyDSMOptionsFlowHandler(OptionsFlow):
    config_entry: Any
    def __init__(self, config_entry: ConfigEntry) -> None: ...
    async def async_step_init(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...

def _login_and_fetch_syno_info(api: SynologyDSM, otp_code: str) -> str: ...

class InvalidData(exceptions.HomeAssistantError): ...



from .const import DATA_CAMERAS as DATA_CAMERAS, DATA_EVENTS as DATA_EVENTS, DOMAIN as DOMAIN, MANUFACTURER as MANUFACTURER
from homeassistant.components.media_player.const import MEDIA_CLASS_DIRECTORY as MEDIA_CLASS_DIRECTORY, MEDIA_CLASS_VIDEO as MEDIA_CLASS_VIDEO, MEDIA_TYPE_VIDEO as MEDIA_TYPE_VIDEO
from homeassistant.components.media_player.errors import BrowseError as BrowseError
from homeassistant.components.media_source.error import MediaSourceError as MediaSourceError, Unresolvable as Unresolvable
from homeassistant.components.media_source.models import BrowseMediaSource as BrowseMediaSource, MediaSource as MediaSource, MediaSourceItem as MediaSourceItem, PlayMedia as PlayMedia
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from typing import Any

_LOGGER: Any
MIME_TYPE: str

class IncompatibleMediaSource(MediaSourceError): ...

async def async_get_media_source(hass: HomeAssistant) -> NetatmoSource: ...

class NetatmoSource(MediaSource):
    name: str
    hass: Any
    events: Any
    def __init__(self, hass: HomeAssistant) -> None: ...
    async def async_resolve_media(self, item: MediaSourceItem) -> PlayMedia: ...
    async def async_browse_media(self, item: MediaSourceItem, media_types: tuple[str] = ...) -> BrowseMediaSource: ...
    def _browse_media(self, source: str, camera_id: str, event_id: Union[int, None]) -> BrowseMediaSource: ...
    def _build_item_response(self, source: str, camera_id: str, event_id: Union[int, None] = ...) -> BrowseMediaSource: ...

def remove_html_tags(text: str) -> str: ...
def async_parse_identifier(item: MediaSourceItem) -> tuple[str, str, Union[int, None]]: ...



from collections import OrderedDict
from homeassistant import loader as loader
from homeassistant.config import CONF_CORE as CONF_CORE, CONF_PACKAGES as CONF_PACKAGES, CORE_CONFIG_SCHEMA as CORE_CONFIG_SCHEMA, YAML_CONFIG_FILE as YAML_CONFIG_FILE, _format_config_error as _format_config_error, config_per_platform as config_per_platform, extract_domain_configs as extract_domain_configs, load_yaml_config_file as load_yaml_config_file, merge_packages_config as merge_packages_config
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.exceptions import HomeAssistantError as HomeAssistantError
from homeassistant.helpers.typing import ConfigType as ConfigType
from homeassistant.requirements import RequirementsNotFound as RequirementsNotFound, async_get_integration_with_requirements as async_get_integration_with_requirements
from typing import Any, NamedTuple

class CheckConfigError(NamedTuple):
    message: str
    domain: Union[str, None]
    config: Union[ConfigType, None]

class HomeAssistantConfig(OrderedDict):
    errors: Any
    def __init__(self) -> None: ...
    def add_error(self, message: str, domain: Union[str, None] = ..., config: Union[ConfigType, None] = ...) -> HomeAssistantConfig: ...
    @property
    def error_str(self) -> str: ...

async def async_check_ha_config_file(hass: HomeAssistant) -> HomeAssistantConfig: ...



from .const import CONF_PLACE_ID as CONF_PLACE_ID, CONF_SERVICE_ID as CONF_SERVICE_ID, DATA_COORDINATOR as DATA_COORDINATOR, DOMAIN as DOMAIN, LOGGER as LOGGER
from aiorecollect.client import PickupType as PickupType
from homeassistant.components.sensor import PLATFORM_SCHEMA as PLATFORM_SCHEMA, SensorEntity as SensorEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry, SOURCE_IMPORT as SOURCE_IMPORT
from homeassistant.const import ATTR_ATTRIBUTION as ATTR_ATTRIBUTION, CONF_FRIENDLY_NAME as CONF_FRIENDLY_NAME, CONF_NAME as CONF_NAME, DEVICE_CLASS_TIMESTAMP as DEVICE_CLASS_TIMESTAMP
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.typing import ConfigType as ConfigType, DiscoveryInfoType as DiscoveryInfoType
from homeassistant.helpers.update_coordinator import CoordinatorEntity as CoordinatorEntity, DataUpdateCoordinator as DataUpdateCoordinator
from homeassistant.util.dt import as_utc as as_utc
from typing import Any

ATTR_PICKUP_TYPES: str
ATTR_AREA_NAME: str
ATTR_NEXT_PICKUP_TYPES: str
ATTR_NEXT_PICKUP_DATE: str
DEFAULT_ATTRIBUTION: str
DEFAULT_NAME: str

def async_get_pickup_type_names(entry: ConfigEntry, pickup_types: list[PickupType]) -> list[str]: ...
async def async_setup_platform(hass: HomeAssistant, config: ConfigType, async_add_entities: AddEntitiesCallback, discovery_info: Union[DiscoveryInfoType, None] = ...) -> None: ...
async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class ReCollectWasteSensor(CoordinatorEntity, SensorEntity):
    _attr_device_class: Any
    _attr_extra_state_attributes: Any
    _attr_name: Any
    _attr_unique_id: Any
    _entry: Any
    def __init__(self, coordinator: DataUpdateCoordinator, entry: ConfigEntry) -> None: ...
    def _handle_coordinator_update(self) -> None: ...
    async def async_added_to_hass(self) -> None: ...
    _attr_state: Any
    def update_from_latest_data(self) -> None: ...



import voluptuous as vol
from .const import ATTR_COMMAND_CLASS as ATTR_COMMAND_CLASS, ATTR_DATA_TYPE as ATTR_DATA_TYPE, ATTR_ENDPOINT as ATTR_ENDPOINT, ATTR_EVENT as ATTR_EVENT, ATTR_EVENT_LABEL as ATTR_EVENT_LABEL, ATTR_EVENT_TYPE as ATTR_EVENT_TYPE, ATTR_LABEL as ATTR_LABEL, ATTR_PROPERTY as ATTR_PROPERTY, ATTR_PROPERTY_KEY as ATTR_PROPERTY_KEY, ATTR_TYPE as ATTR_TYPE, ATTR_VALUE as ATTR_VALUE, ATTR_VALUE_RAW as ATTR_VALUE_RAW, DOMAIN as DOMAIN, ZWAVE_JS_NOTIFICATION_EVENT as ZWAVE_JS_NOTIFICATION_EVENT, ZWAVE_JS_VALUE_NOTIFICATION_EVENT as ZWAVE_JS_VALUE_NOTIFICATION_EVENT
from .helpers import async_get_node_from_device_id as async_get_node_from_device_id, async_get_node_status_sensor_entity_id as async_get_node_status_sensor_entity_id, get_zwave_value_from_config as get_zwave_value_from_config
from homeassistant.components.automation import AutomationActionType as AutomationActionType
from homeassistant.components.device_automation import DEVICE_TRIGGER_BASE_SCHEMA as DEVICE_TRIGGER_BASE_SCHEMA
from homeassistant.components.homeassistant.triggers import event as event, state as state
from homeassistant.const import CONF_DEVICE_ID as CONF_DEVICE_ID, CONF_DOMAIN as CONF_DOMAIN, CONF_ENTITY_ID as CONF_ENTITY_ID, CONF_PLATFORM as CONF_PLATFORM, CONF_TYPE as CONF_TYPE
from homeassistant.core import CALLBACK_TYPE as CALLBACK_TYPE, HomeAssistant as HomeAssistant
from homeassistant.exceptions import HomeAssistantError as HomeAssistantError
from homeassistant.helpers import device_registry as device_registry, entity_registry as entity_registry
from homeassistant.helpers.typing import ConfigType as ConfigType
from typing import Any

CONF_SUBTYPE: str
CONF_VALUE_ID: str
ENTRY_CONTROL_NOTIFICATION: str
NOTIFICATION_NOTIFICATION: str
BASIC_VALUE_NOTIFICATION: str
CENTRAL_SCENE_VALUE_NOTIFICATION: str
SCENE_ACTIVATION_VALUE_NOTIFICATION: str
NODE_STATUS: str
NOTIFICATION_EVENT_CC_MAPPINGS: Any
BASE_EVENT_SCHEMA: Any
NOTIFICATION_NOTIFICATION_SCHEMA: Any
ENTRY_CONTROL_NOTIFICATION_SCHEMA: Any
BASE_VALUE_NOTIFICATION_EVENT_SCHEMA: Any
BASIC_VALUE_NOTIFICATION_SCHEMA: Any
CENTRAL_SCENE_VALUE_NOTIFICATION_SCHEMA: Any
SCENE_ACTIVATION_VALUE_NOTIFICATION_SCHEMA: Any
BASE_STATE_SCHEMA: Any
NODE_STATUSES: Any
NODE_STATUS_SCHEMA: Any
TRIGGER_SCHEMA: Any

async def async_get_triggers(hass: HomeAssistant, device_id: str) -> list[dict]: ...
def copy_available_params(input_dict: dict, output_dict: dict, params: list[str]) -> None: ...
async def async_attach_trigger(hass: HomeAssistant, config: ConfigType, action: AutomationActionType, automation_info: dict) -> CALLBACK_TYPE: ...
async def async_get_trigger_capabilities(hass: HomeAssistant, config: ConfigType) -> dict[str, vol.Schema]: ...



from . import AUTH_PROVIDERS as AUTH_PROVIDERS, AUTH_PROVIDER_SCHEMA as AUTH_PROVIDER_SCHEMA, AuthProvider as AuthProvider, LoginFlow as LoginFlow
from ..models import Credentials as Credentials, UserMeta as UserMeta
from collections.abc import Mapping
from homeassistant.core import callback as callback
from homeassistant.data_entry_flow import FlowResult as FlowResult
from homeassistant.exceptions import HomeAssistantError as HomeAssistantError
from typing import Any

USER_SCHEMA: Any
CONFIG_SCHEMA: Any

class InvalidAuthError(HomeAssistantError): ...

class ExampleAuthProvider(AuthProvider):
    async def async_login_flow(self, context: Union[dict, None]) -> LoginFlow: ...
    def async_validate_login(self, username: str, password: str) -> None: ...
    async def async_get_or_create_credentials(self, flow_result: Mapping[str, str]) -> Credentials: ...
    async def async_user_meta_for_credentials(self, credentials: Credentials) -> UserMeta: ...

class ExampleLoginFlow(LoginFlow):
    async def async_step_init(self, user_input: Union[dict[str, str], None] = ...) -> FlowResult: ...



from homeassistant.components import system_health as system_health
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from typing import Any, Final

API_ENDPOINT: Final[str]

def async_register(hass: HomeAssistant, register: system_health.SystemHealthRegistration) -> None: ...
async def system_health_info(hass: HomeAssistant) -> dict[str, Any]: ...



from .const import ATTR_ENTRY_TYPE as ATTR_ENTRY_TYPE, DOMAIN as DOMAIN, ENTRY_TYPE_SERVICE as ENTRY_TYPE_SERVICE, SENSORS as SENSORS
from .models import ForecastSolarSensorEntityDescription as ForecastSolarSensorEntityDescription
from homeassistant.components.sensor import SensorEntity as SensorEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import ATTR_IDENTIFIERS as ATTR_IDENTIFIERS, ATTR_MANUFACTURER as ATTR_MANUFACTURER, ATTR_NAME as ATTR_NAME
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.typing import StateType as StateType
from homeassistant.helpers.update_coordinator import CoordinatorEntity as CoordinatorEntity, DataUpdateCoordinator as DataUpdateCoordinator
from typing import Any

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class ForecastSolarSensorEntity(CoordinatorEntity, SensorEntity):
    entity_description: ForecastSolarSensorEntityDescription
    entity_id: Any
    _attr_unique_id: Any
    _attr_device_info: Any
    def __init__(self, entry_id: str, coordinator: DataUpdateCoordinator, entity_description: ForecastSolarSensorEntityDescription) -> None: ...
    @property
    def state(self) -> StateType: ...



import datetime
from .const import DATA_SONOS as DATA_SONOS, MEDIA_TYPES_TO_SONOS as MEDIA_TYPES_TO_SONOS, PLAYABLE_MEDIA_TYPES as PLAYABLE_MEDIA_TYPES, SONOS_CREATE_MEDIA_PLAYER as SONOS_CREATE_MEDIA_PLAYER, SONOS_STATE_PLAYING as SONOS_STATE_PLAYING, SONOS_STATE_TRANSITIONING as SONOS_STATE_TRANSITIONING, SOURCE_LINEIN as SOURCE_LINEIN, SOURCE_TV as SOURCE_TV
from .entity import SonosEntity as SonosEntity
from .helpers import soco_error as soco_error
from .media_browser import build_item_response as build_item_response, get_media as get_media, library_payload as library_payload
from .speaker import SonosMedia as SonosMedia, SonosSpeaker as SonosSpeaker
from homeassistant.components.media_player import MediaPlayerEntity as MediaPlayerEntity
from homeassistant.components.media_player.const import ATTR_MEDIA_ENQUEUE as ATTR_MEDIA_ENQUEUE, MEDIA_TYPE_ALBUM as MEDIA_TYPE_ALBUM, MEDIA_TYPE_ARTIST as MEDIA_TYPE_ARTIST, MEDIA_TYPE_MUSIC as MEDIA_TYPE_MUSIC, MEDIA_TYPE_PLAYLIST as MEDIA_TYPE_PLAYLIST, MEDIA_TYPE_TRACK as MEDIA_TYPE_TRACK, REPEAT_MODE_ALL as REPEAT_MODE_ALL, REPEAT_MODE_OFF as REPEAT_MODE_OFF, REPEAT_MODE_ONE as REPEAT_MODE_ONE, SUPPORT_BROWSE_MEDIA as SUPPORT_BROWSE_MEDIA, SUPPORT_CLEAR_PLAYLIST as SUPPORT_CLEAR_PLAYLIST, SUPPORT_NEXT_TRACK as SUPPORT_NEXT_TRACK, SUPPORT_PAUSE as SUPPORT_PAUSE, SUPPORT_PLAY as SUPPORT_PLAY, SUPPORT_PLAY_MEDIA as SUPPORT_PLAY_MEDIA, SUPPORT_PREVIOUS_TRACK as SUPPORT_PREVIOUS_TRACK, SUPPORT_REPEAT_SET as SUPPORT_REPEAT_SET, SUPPORT_SEEK as SUPPORT_SEEK, SUPPORT_SELECT_SOURCE as SUPPORT_SELECT_SOURCE, SUPPORT_SHUFFLE_SET as SUPPORT_SHUFFLE_SET, SUPPORT_STOP as SUPPORT_STOP, SUPPORT_VOLUME_MUTE as SUPPORT_VOLUME_MUTE, SUPPORT_VOLUME_SET as SUPPORT_VOLUME_SET
from homeassistant.components.media_player.errors import BrowseError as BrowseError
from homeassistant.components.plex.const import PLEX_URI_SCHEME as PLEX_URI_SCHEME
from homeassistant.components.plex.services import play_on_sonos as play_on_sonos
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import ATTR_TIME as ATTR_TIME, STATE_IDLE as STATE_IDLE, STATE_PAUSED as STATE_PAUSED, STATE_PLAYING as STATE_PLAYING
from homeassistant.core import HomeAssistant as HomeAssistant, ServiceCall as ServiceCall, callback as callback
from homeassistant.helpers import entity_platform as entity_platform, service as service
from homeassistant.helpers.dispatcher import async_dispatcher_connect as async_dispatcher_connect
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.network import is_internal_request as is_internal_request
from typing import Any

_LOGGER: Any
SUPPORT_SONOS: Any
VOLUME_INCREMENT: int
REPEAT_TO_SONOS: Any
SONOS_TO_REPEAT: Any
ATTR_SONOS_GROUP: str
UPNP_ERRORS_TO_IGNORE: Any
SERVICE_JOIN: str
SERVICE_UNJOIN: str
SERVICE_SNAPSHOT: str
SERVICE_RESTORE: str
SERVICE_SET_TIMER: str
SERVICE_CLEAR_TIMER: str
SERVICE_UPDATE_ALARM: str
SERVICE_SET_OPTION: str
SERVICE_PLAY_QUEUE: str
SERVICE_REMOVE_FROM_QUEUE: str
ATTR_SLEEP_TIME: str
ATTR_ALARM_ID: str
ATTR_VOLUME: str
ATTR_ENABLED: str
ATTR_INCLUDE_LINKED_ZONES: str
ATTR_MASTER: str
ATTR_WITH_GROUP: str
ATTR_BUTTONS_ENABLED: str
ATTR_CROSSFADE: str
ATTR_NIGHT_SOUND: str
ATTR_SPEECH_ENHANCE: str
ATTR_QUEUE_POSITION: str
ATTR_STATUS_LIGHT: str

async def async_setup_entry(hass: HomeAssistant, config_entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class SonosMediaPlayerEntity(SonosEntity, MediaPlayerEntity):
    @property
    def coordinator(self) -> SonosSpeaker: ...
    @property
    def unique_id(self) -> str: ...
    def __hash__(self) -> int: ...
    @property
    def name(self) -> str: ...
    @property
    def state(self) -> str: ...
    async def async_update(self) -> None: ...
    def _update(self) -> None: ...
    @property
    def volume_level(self) -> Union[float, None]: ...
    @property
    def is_volume_muted(self) -> Union[bool, None]: ...
    @property
    def shuffle(self) -> Union[str, None]: ...
    @property
    def repeat(self) -> Union[str, None]: ...
    @property
    def media(self) -> SonosMedia: ...
    @property
    def media_content_id(self) -> Union[str, None]: ...
    @property
    def media_content_type(self) -> str: ...
    @property
    def media_duration(self) -> Union[float, None]: ...
    @property
    def media_position(self) -> Union[float, None]: ...
    @property
    def media_position_updated_at(self) -> Union[datetime.datetime, None]: ...
    @property
    def media_image_url(self) -> Union[str, None]: ...
    @property
    def media_channel(self) -> Union[str, None]: ...
    @property
    def media_playlist(self) -> Union[str, None]: ...
    @property
    def media_artist(self) -> Union[str, None]: ...
    @property
    def media_album_name(self) -> Union[str, None]: ...
    @property
    def media_title(self) -> Union[str, None]: ...
    @property
    def source(self) -> Union[str, None]: ...
    @property
    def supported_features(self) -> int: ...
    def volume_up(self) -> None: ...
    def volume_down(self) -> None: ...
    def set_volume_level(self, volume: str) -> None: ...
    def set_shuffle(self, shuffle: str) -> None: ...
    def set_repeat(self, repeat: str) -> None: ...
    def mute_volume(self, mute: bool) -> None: ...
    def select_source(self, source: str) -> None: ...
    @property
    def source_list(self) -> list[str]: ...
    def media_play(self) -> None: ...
    def media_stop(self) -> None: ...
    def media_pause(self) -> None: ...
    def media_next_track(self) -> None: ...
    def media_previous_track(self) -> None: ...
    def media_seek(self, position: str) -> None: ...
    def clear_playlist(self) -> None: ...
    def play_media(self, media_type: str, media_id: str, **kwargs: Any) -> None: ...
    def set_sleep_timer(self, sleep_time: int) -> None: ...
    def clear_sleep_timer(self) -> None: ...
    def set_alarm(self, alarm_id: int, time: Union[datetime.datetime, None] = ..., volume: Union[float, None] = ..., enabled: Union[bool, None] = ..., include_linked_zones: Union[bool, None] = ...) -> None: ...
    def set_option(self, buttons_enabled: Union[bool, None] = ..., crossfade: Union[bool, None] = ..., night_sound: Union[bool, None] = ..., speech_enhance: Union[bool, None] = ..., status_light: Union[bool, None] = ...) -> None: ...
    def play_queue(self, queue_position: int = ...) -> None: ...
    def remove_from_queue(self, queue_position: int = ...) -> None: ...
    @property
    def extra_state_attributes(self) -> dict[str, Any]: ...
    async def async_get_browse_image(self, media_content_type: Union[str, None], media_content_id: Union[str, None], media_image_id: Union[str, None] = ...) -> tuple[Union[None, str], Union[None, str]]: ...
    async def async_browse_media(self, media_content_type: Union[str, None] = ..., media_content_id: Union[str, None] = ...) -> Any: ...



import pyatmo
from aiohttp import ClientSession as ClientSession
from homeassistant.helpers import config_entry_oauth2_flow as config_entry_oauth2_flow
from typing import Any

class AsyncConfigEntryNetatmoAuth(pyatmo.auth.AbstractAsyncAuth):
    _oauth_session: Any
    def __init__(self, websession: ClientSession, oauth_session: config_entry_oauth2_flow.OAuth2Session) -> None: ...
    async def async_get_access_token(self) -> str: ...



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['homeassistant-stubs']

package_data = \
{'': ['*'],
 'homeassistant-stubs': ['auth/*',
                         'auth/mfa_modules/*',
                         'auth/permissions/*',
                         'auth/providers/*',
                         'components/*',
                         'components/accuweather/*',
                         'components/acer_projector/*',
                         'components/actiontec/*',
                         'components/aftership/*',
                         'components/air_quality/*',
                         'components/airly/*',
                         'components/airvisual/*',
                         'components/aladdin_connect/*',
                         'components/alarm_control_panel/*',
                         'components/amazon_polly/*',
                         'components/ambee/*',
                         'components/ambient_station/*',
                         'components/ampio/*',
                         'components/automation/*',
                         'components/binary_sensor/*',
                         'components/bluetooth_tracker/*',
                         'components/bond/*',
                         'components/braviatv/*',
                         'components/brother/*',
                         'components/calendar/*',
                         'components/camera/*',
                         'components/canary/*',
                         'components/cover/*',
                         'components/device_automation/*',
                         'components/device_tracker/*',
                         'components/devolo_home_control/*',
                         'components/dnsip/*',
                         'components/dsmr/*',
                         'components/dunehd/*',
                         'components/elgato/*',
                         'components/energy/*',
                         'components/esphome/*',
                         'components/fastdotcom/*',
                         'components/fitbit/*',
                         'components/flunearyou/*',
                         'components/forecast_solar/*',
                         'components/fritz/*',
                         'components/fritzbox/*',
                         'components/frontend/*',
                         'components/geo_location/*',
                         'components/gios/*',
                         'components/group/*',
                         'components/guardian/*',
                         'components/history/*',
                         'components/homeassistant/triggers/*',
                         'components/http/*',
                         'components/huawei_lte/*',
                         'components/hyperion/*',
                         'components/image_processing/*',
                         'components/integration/*',
                         'components/knx/*',
                         'components/kraken/*',
                         'components/lcn/*',
                         'components/light/*',
                         'components/local_ip/*',
                         'components/lock/*',
                         'components/mailbox/*',
                         'components/media_player/*',
                         'components/mysensors/*',
                         'components/nam/*',
                         'components/nest/*',
                         'components/nest/legacy/*',
                         'components/netatmo/*',
                         'components/network/*',
                         'components/no_ip/*',
                         'components/notify/*',
                         'components/notion/*',
                         'components/number/*',
                         'components/onewire/*',
                         'components/openuv/*',
                         'components/persistent_notification/*',
                         'components/pi_hole/*',
                         'components/proximity/*',
                         'components/rainmachine/*',
                         'components/recollect_waste/*',
                         'components/recorder/*',
                         'components/remote/*',
                         'components/renault/*',
                         'components/rituals_perfume_genie/*',
                         'components/scene/*',
                         'components/select/*',
                         'components/sensor/*',
                         'components/shelly/*',
                         'components/simplisafe/*',
                         'components/slack/*',
                         'components/sonos/*',
                         'components/ssdp/*',
                         'components/stream/*',
                         'components/sun/*',
                         'components/switch/*',
                         'components/switcher_kis/*',
                         'components/synology_dsm/*',
                         'components/systemmonitor/*',
                         'components/tag/*',
                         'components/tcp/*',
                         'components/tile/*',
                         'components/tts/*',
                         'components/upcloud/*',
                         'components/uptime/*',
                         'components/vacuum/*',
                         'components/water_heater/*',
                         'components/weather/*',
                         'components/websocket_api/*',
                         'components/zeroconf/*',
                         'components/zodiac/*',
                         'components/zone/*',
                         'components/zwave_js/*',
                         'generated/*',
                         'helpers/*',
                         'scripts/*',
                         'scripts/benchmark/*',
                         'scripts/macos/*',
                         'util/*',
                         'util/yaml/*']}

install_requires = \
['homeassistant==2021.8.2']

setup_kwargs = {
    'name': 'homeassistant-stubs',
    'version': '2021.8.2',
    'description': 'PEP 484 typing stubs for Home Assistant Core',
    'long_description': "# PEP 484 stubs for Home Assistant Core\n\n[![CI](https://github.com/KapJI/homeassistant-stubs/actions/workflows/ci.yaml/badge.svg)](https://github.com/KapJI/homeassistant-stubs/actions/workflows/ci.yaml)\n[![PyPI version](https://img.shields.io/pypi/v/homeassistant-stubs)](https://pypi.org/project/homeassistant-stubs/)\n\nThis is unofficial stub-only package generated from [Home Assistant Core](https://github.com/home-assistant/core) sources.\nYou can use it to enable type checks against Home Assistant code in your custom component or AppDaemon app.\n\n## How to use\n\nAdd it to dev dependencies of your project.\nI recommend to use [Poetry](https://python-poetry.org/) for managing dependencies:\n\n```shell\npoetry add --dev homeassistant-stubs\n```\n\nPlease note that only stubs from strictly typed modules are added in this package.\nThis includes all core modules and some components.\nGeneric components like `sensor`, `light` or `media_player` are already typed.\n\nIf your project imports not yet typed components, `mypy` will be unable to find that module.\nThe best thing you can do to fix this is to submit PR to HA Core which adds type hints for these components.\nAfter that stubs for these components will become available in this package.\n\n## Motivation\n\nHome Assistant maintainers don't want to distribute typing information with `homeassistant` package\n([[1]](https://github.com/home-assistant/core/pull/28866),\n[[2]](https://github.com/home-assistant/core/pull/47796)).\nThe reason is that [PEP 561](https://www.python.org/dev/peps/pep-0561/#packaging-type-information)\nsays that `py.typed` marker is applied recursively and the whole package must support type checking.\nBut many of the Home Assistant components are currently not type checked.\n\n## How it works\n\n- `update_stubs.py` script extracts list of strictly typed modules from Home Assistant `setup.cfg`.\n- Then it runs `stubgen` which is shipped with `mypy` to generate typing stubs.\n- New versions are generated and published automatically every 12 hours.\n",
    'author': 'Ruslan Sayfutdinov',
    'author_email': 'ruslan@sayfutdinov.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/KapJI/homeassistant-stubs',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



from .common import FritzBoxBaseEntity as FritzBoxBaseEntity, FritzBoxTools as FritzBoxTools
from .const import DOMAIN as DOMAIN
from homeassistant.components.binary_sensor import BinarySensorEntity as BinarySensorEntity, DEVICE_CLASS_CONNECTIVITY as DEVICE_CLASS_CONNECTIVITY
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from typing import Any

_LOGGER: Any

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class FritzBoxConnectivitySensor(FritzBoxBaseEntity, BinarySensorEntity):
    _unique_id: Any
    _name: Any
    _is_on: bool
    _is_available: bool
    def __init__(self, fritzbox_tools: FritzBoxTools, device_friendly_name: str) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def device_class(self) -> str: ...
    @property
    def is_on(self) -> bool: ...
    @property
    def unique_id(self) -> str: ...
    @property
    def available(self) -> bool: ...
    def update(self) -> None: ...



from .const import CONF_PLACE_ID as CONF_PLACE_ID, CONF_SERVICE_ID as CONF_SERVICE_ID, DATA_COORDINATOR as DATA_COORDINATOR, DOMAIN as DOMAIN, LOGGER as LOGGER
from aiorecollect.client import PickupEvent as PickupEvent
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers import aiohttp_client as aiohttp_client
from homeassistant.helpers.update_coordinator import DataUpdateCoordinator as DataUpdateCoordinator, UpdateFailed as UpdateFailed
from typing import Any

DEFAULT_NAME: str
DEFAULT_UPDATE_INTERVAL: Any
PLATFORMS: Any

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...
async def async_reload_entry(hass: HomeAssistant, entry: ConfigEntry) -> None: ...
async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...



from .const import CMD_DICT as CMD_DICT, CONF_WRITE_TIMEOUT as CONF_WRITE_TIMEOUT, DEFAULT_NAME as DEFAULT_NAME, DEFAULT_TIMEOUT as DEFAULT_TIMEOUT, DEFAULT_WRITE_TIMEOUT as DEFAULT_WRITE_TIMEOUT, ECO_MODE as ECO_MODE, ICON as ICON, INPUT_SOURCE as INPUT_SOURCE, LAMP as LAMP, LAMP_HOURS as LAMP_HOURS
from homeassistant.components.switch import PLATFORM_SCHEMA as PLATFORM_SCHEMA, SwitchEntity as SwitchEntity
from homeassistant.const import CONF_FILENAME as CONF_FILENAME, CONF_NAME as CONF_NAME, CONF_TIMEOUT as CONF_TIMEOUT, STATE_OFF as STATE_OFF, STATE_ON as STATE_ON, STATE_UNKNOWN as STATE_UNKNOWN
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.typing import ConfigType as ConfigType, DiscoveryInfoType as DiscoveryInfoType
from typing import Any

_LOGGER: Any

def setup_platform(hass: HomeAssistant, config: ConfigType, add_entities: AddEntitiesCallback, discovery_info: DiscoveryInfoType) -> None: ...

class AcerSwitch(SwitchEntity):
    _attr_icon: Any
    ser: Any
    _serial_port: Any
    _attr_name: Any
    _attributes: Any
    def __init__(self, serial_port: str, name: str, timeout: int, write_timeout: int) -> None: ...
    def _write_read(self, msg: str) -> str: ...
    def _write_read_format(self, msg: str) -> str: ...
    _attr_is_on: bool
    _attr_available: bool
    _attr_extra_state_attributes: Any
    def update(self) -> None: ...
    def turn_on(self, **kwargs: Any) -> None: ...
    def turn_off(self, **kwargs: Any) -> None: ...



from homeassistant import runner as runner
from homeassistant.auth import auth_manager_from_config as auth_manager_from_config
from homeassistant.config import get_default_config_dir as get_default_config_dir
from homeassistant.core import HomeAssistant as HomeAssistant

def run(args) -> None: ...
async def run_command(args) -> None: ...
async def list_users(hass, provider, args) -> None: ...
async def add_user(hass, provider, args) -> None: ...
async def validate_login(hass, provider, args) -> None: ...
async def change_password(hass, provider, args) -> None: ...



import asyncio
from .const import API_SENSOR_PAIRED_SENSOR_STATUS as API_SENSOR_PAIRED_SENSOR_STATUS, API_SENSOR_PAIR_DUMP as API_SENSOR_PAIR_DUMP, API_SYSTEM_DIAGNOSTICS as API_SYSTEM_DIAGNOSTICS, API_SYSTEM_ONBOARD_SENSOR_STATUS as API_SYSTEM_ONBOARD_SENSOR_STATUS, API_VALVE_STATUS as API_VALVE_STATUS, API_WIFI_STATUS as API_WIFI_STATUS, CONF_UID as CONF_UID, DATA_CLIENT as DATA_CLIENT, DATA_COORDINATOR as DATA_COORDINATOR, DATA_COORDINATOR_PAIRED_SENSOR as DATA_COORDINATOR_PAIRED_SENSOR, DATA_PAIRED_SENSOR_MANAGER as DATA_PAIRED_SENSOR_MANAGER, DATA_UNSUB_DISPATCHER_CONNECT as DATA_UNSUB_DISPATCHER_CONNECT, DOMAIN as DOMAIN, LOGGER as LOGGER, SIGNAL_PAIRED_SENSOR_COORDINATOR_ADDED as SIGNAL_PAIRED_SENSOR_COORDINATOR_ADDED
from .util import GuardianDataUpdateCoordinator as GuardianDataUpdateCoordinator
from aioguardian import Client
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import ATTR_ATTRIBUTION as ATTR_ATTRIBUTION, CONF_IP_ADDRESS as CONF_IP_ADDRESS, CONF_PORT as CONF_PORT
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.dispatcher import async_dispatcher_send as async_dispatcher_send
from homeassistant.helpers.update_coordinator import CoordinatorEntity as CoordinatorEntity, DataUpdateCoordinator as DataUpdateCoordinator
from typing import Any

PLATFORMS: Any

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...
async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...

class PairedSensorManager:
    _api_lock: Any
    _client: Any
    _entry: Any
    _hass: Any
    _paired_uids: Any
    def __init__(self, hass: HomeAssistant, entry: ConfigEntry, client: Client, api_lock: asyncio.Lock) -> None: ...
    async def async_pair_sensor(self, uid: str) -> None: ...
    async def async_process_latest_paired_sensor_uids(self) -> None: ...
    async def async_unpair_sensor(self, uid: str) -> None: ...

class GuardianEntity(CoordinatorEntity):
    _attr_device_class: Any
    _attr_device_info: Any
    _attr_extra_state_attributes: Any
    _attr_icon: Any
    _attr_name: Any
    _entry: Any
    def __init__(self, entry: ConfigEntry, kind: str, name: str, device_class: Union[str, None], icon: Union[str, None]) -> None: ...
    def _async_update_from_latest_data(self) -> None: ...

class PairedSensorEntity(GuardianEntity):
    _attr_device_info: Any
    _attr_name: Any
    _attr_unique_id: Any
    _kind: Any
    coordinator: Any
    def __init__(self, entry: ConfigEntry, coordinator: DataUpdateCoordinator, kind: str, name: str, device_class: Union[str, None], icon: Union[str, None]) -> None: ...
    async def async_added_to_hass(self) -> None: ...

class ValveControllerEntity(GuardianEntity):
    _attr_device_info: Any
    _attr_name: Any
    _attr_unique_id: Any
    _kind: Any
    coordinators: Any
    def __init__(self, entry: ConfigEntry, coordinators: dict[str, DataUpdateCoordinator], kind: str, name: str, device_class: Union[str, None], icon: Union[str, None]) -> None: ...
    @property
    def available(self) -> bool: ...
    async def _async_continue_entity_setup(self) -> None: ...
    def async_add_coordinator_update_listener(self, api: str) -> None: ...
    async def async_added_to_hass(self) -> None: ...
    async def async_update(self) -> None: ...



from homeassistant.components.sensor import STATE_CLASS_MEASUREMENT as STATE_CLASS_MEASUREMENT, SensorEntityDescription as SensorEntityDescription
from homeassistant.const import CONCENTRATION_MICROGRAMS_PER_CUBIC_METER as CONCENTRATION_MICROGRAMS_PER_CUBIC_METER, CONCENTRATION_PARTS_PER_BILLION as CONCENTRATION_PARTS_PER_BILLION, CONCENTRATION_PARTS_PER_CUBIC_METER as CONCENTRATION_PARTS_PER_CUBIC_METER, CONCENTRATION_PARTS_PER_MILLION as CONCENTRATION_PARTS_PER_MILLION, DEVICE_CLASS_CO as DEVICE_CLASS_CO
from typing import Any, Final

DOMAIN: Final[str]
LOGGER: Any
SCAN_INTERVAL: Any
ATTR_ENTRY_TYPE: Final[str]
ENTRY_TYPE_SERVICE: Final[str]
DEVICE_CLASS_AMBEE_RISK: Final[str]
SERVICE_AIR_QUALITY: Final[str]
SERVICE_POLLEN: Final[str]
SERVICES: dict[str, str]
SENSORS: dict[str, list[SensorEntityDescription]]



from .common import FritzBoxTools as FritzBoxTools
from .const import DEFAULT_HOST as DEFAULT_HOST, DEFAULT_PORT as DEFAULT_PORT, DOMAIN as DOMAIN, ERROR_AUTH_INVALID as ERROR_AUTH_INVALID, ERROR_CANNOT_CONNECT as ERROR_CANNOT_CONNECT, ERROR_UNKNOWN as ERROR_UNKNOWN
from homeassistant.components.device_tracker.const import CONF_CONSIDER_HOME as CONF_CONSIDER_HOME, DEFAULT_CONSIDER_HOME as DEFAULT_CONSIDER_HOME
from homeassistant.components.ssdp import ATTR_SSDP_LOCATION as ATTR_SSDP_LOCATION, ATTR_UPNP_FRIENDLY_NAME as ATTR_UPNP_FRIENDLY_NAME, ATTR_UPNP_UDN as ATTR_UPNP_UDN
from homeassistant.config_entries import ConfigEntry as ConfigEntry, ConfigFlow as ConfigFlow, OptionsFlow as OptionsFlow
from homeassistant.const import CONF_HOST as CONF_HOST, CONF_PASSWORD as CONF_PASSWORD, CONF_PORT as CONF_PORT, CONF_USERNAME as CONF_USERNAME
from homeassistant.core import callback as callback
from homeassistant.data_entry_flow import FlowResult as FlowResult
from homeassistant.helpers.typing import DiscoveryInfoType as DiscoveryInfoType
from typing import Any
from urllib.parse import ParseResult as ParseResult

_LOGGER: Any

class FritzBoxToolsFlowHandler(ConfigFlow):
    VERSION: int
    @staticmethod
    def async_get_options_flow(config_entry: ConfigEntry) -> OptionsFlow: ...
    _host: Any
    _entry: Any
    _name: Any
    _password: Any
    _port: Any
    _username: Any
    fritz_tools: Any
    def __init__(self) -> None: ...
    async def fritz_tools_init(self) -> Union[str, None]: ...
    async def async_check_configured_entry(self) -> Union[ConfigEntry, None]: ...
    def _async_create_entry(self) -> FlowResult: ...
    async def async_step_ssdp(self, discovery_info: DiscoveryInfoType) -> FlowResult: ...
    async def async_step_confirm(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    def _show_setup_form_init(self, errors: Union[dict[str, str], None] = ...) -> FlowResult: ...
    def _show_setup_form_confirm(self, errors: Union[dict[str, str], None] = ...) -> FlowResult: ...
    async def async_step_user(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    async def async_step_reauth(self, data: dict[str, Any]) -> FlowResult: ...
    def _show_setup_form_reauth_confirm(self, user_input: dict[str, Any], errors: Union[dict[str, str], None] = ...) -> FlowResult: ...
    async def async_step_reauth_confirm(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    async def async_step_import(self, import_config: dict[str, Any]) -> FlowResult: ...

class FritzBoxToolsOptionsFlowHandler(OptionsFlow):
    config_entry: Any
    def __init__(self, config_entry: ConfigEntry) -> None: ...
    async def async_step_init(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...



from typing import Any

CONF_ACTION: str
CONF_TRIGGER: str
CONF_TRIGGER_VARIABLES: str
DOMAIN: str
CONF_HIDE_ENTITY: str
CONF_CONDITION_TYPE: str
CONF_INITIAL_STATE: str
CONF_BLUEPRINT: str
CONF_INPUT: str
CONF_TRACE: str
DEFAULT_INITIAL_STATE: bool
LOGGER: Any



from .helpers import on_unload as on_unload
from homeassistant.components import mysensors as mysensors
from homeassistant.components.device_tracker import DOMAIN as DOMAIN
from homeassistant.components.mysensors import DevId as DevId
from homeassistant.components.mysensors.const import ATTR_GATEWAY_ID as ATTR_GATEWAY_ID, DiscoveryInfo as DiscoveryInfo, GatewayId as GatewayId
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.dispatcher import async_dispatcher_connect as async_dispatcher_connect
from homeassistant.util import slugify as slugify
from typing import Any, Callable

async def async_setup_scanner(hass: HomeAssistant, config: dict[str, Any], async_see: Callable, discovery_info: Union[DiscoveryInfo, None] = ...) -> bool: ...

class MySensorsDeviceScanner(mysensors.device.MySensorsDevice):
    async_see: Any
    hass: Any
    def __init__(self, hass: HomeAssistant, async_see: Callable, *args: Any) -> None: ...
    async def _async_update_callback(self) -> None: ...



from .models import ForecastSolarSensorEntityDescription as ForecastSolarSensorEntityDescription
from homeassistant.components.sensor import STATE_CLASS_MEASUREMENT as STATE_CLASS_MEASUREMENT
from homeassistant.const import DEVICE_CLASS_ENERGY as DEVICE_CLASS_ENERGY, DEVICE_CLASS_POWER as DEVICE_CLASS_POWER, DEVICE_CLASS_TIMESTAMP as DEVICE_CLASS_TIMESTAMP, ENERGY_KILO_WATT_HOUR as ENERGY_KILO_WATT_HOUR, POWER_WATT as POWER_WATT
from typing import Final

DOMAIN: str
CONF_DECLINATION: str
CONF_AZIMUTH: str
CONF_MODULES_POWER: str
CONF_DAMPING: str
ATTR_ENTRY_TYPE: Final[str]
ENTRY_TYPE_SERVICE: Final[str]
SENSORS: tuple[ForecastSolarSensorEntityDescription, ...]



from .const import DATA_CLIENT as DATA_CLIENT, DOMAIN as DOMAIN
from .discovery import ZwaveDiscoveryInfo as ZwaveDiscoveryInfo
from .entity import ZWaveBaseEntity as ZWaveBaseEntity
from homeassistant.components.number import NumberEntity as NumberEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.dispatcher import async_dispatcher_connect as async_dispatcher_connect
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from typing import Any
from zwave_js_server.client import Client as ZwaveClient

async def async_setup_entry(hass: HomeAssistant, config_entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class ZwaveNumberEntity(ZWaveBaseEntity, NumberEntity):
    _target_value: Any
    _attr_name: Any
    def __init__(self, config_entry: ConfigEntry, client: ZwaveClient, info: ZwaveDiscoveryInfo) -> None: ...
    @property
    def min_value(self) -> float: ...
    @property
    def max_value(self) -> float: ...
    @property
    def value(self) -> Union[float, None]: ...
    @property
    def unit_of_measurement(self) -> Union[str, None]: ...
    async def async_set_value(self, value: float) -> None: ...



import astral
import datetime
from homeassistant.const import SUN_EVENT_SUNRISE as SUN_EVENT_SUNRISE, SUN_EVENT_SUNSET as SUN_EVENT_SUNSET
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.loader import bind_hass as bind_hass
from typing import Any

DATA_LOCATION_CACHE: str
ELEVATION_AGNOSTIC_EVENTS: Any

def get_astral_location(hass: HomeAssistant) -> tuple[astral.location.Location, astral.Elevation]: ...
def get_astral_event_next(hass: HomeAssistant, event: str, utc_point_in_time: Union[datetime.datetime, None] = ..., offset: Union[datetime.timedelta, None] = ...) -> datetime.datetime: ...
def get_location_astral_event_next(location: astral.location.Location, elevation: astral.Elevation, event: str, utc_point_in_time: Union[datetime.datetime, None] = ..., offset: Union[datetime.timedelta, None] = ...) -> datetime.datetime: ...
def get_astral_event_date(hass: HomeAssistant, event: str, date: Union[datetime.date, datetime.datetime, None] = ...) -> Union[datetime.datetime, None]: ...
def is_up(hass: HomeAssistant, utc_point_in_time: Union[datetime.datetime, None] = ...) -> bool: ...



from homeassistant.components.notify import ATTR_DATA as ATTR_DATA, ATTR_MESSAGE as ATTR_MESSAGE, BaseNotificationService as BaseNotificationService, DOMAIN as DOMAIN, PLATFORM_SCHEMA as PLATFORM_SCHEMA
from homeassistant.const import ATTR_SERVICE as ATTR_SERVICE
from typing import Any

CONF_SERVICES: str

def update(input_dict, update_source): ...
async def async_get_service(hass, config, discovery_info: Any | None = ...): ...

class GroupNotifyPlatform(BaseNotificationService):
    hass: Any
    entities: Any
    def __init__(self, hass, entities) -> None: ...
    async def async_send_message(self, message: str = ..., **kwargs) -> None: ...



from .const import BINSENSOR_PORTS as BINSENSOR_PORTS, CONF_CLIMATES as CONF_CLIMATES, CONF_CONNECTIONS as CONF_CONNECTIONS, CONF_DIMMABLE as CONF_DIMMABLE, CONF_DIM_MODE as CONF_DIM_MODE, CONF_LOCKABLE as CONF_LOCKABLE, CONF_MAX_TEMP as CONF_MAX_TEMP, CONF_MIN_TEMP as CONF_MIN_TEMP, CONF_MOTOR as CONF_MOTOR, CONF_OUTPUT as CONF_OUTPUT, CONF_OUTPUTS as CONF_OUTPUTS, CONF_REGISTER as CONF_REGISTER, CONF_REVERSE_TIME as CONF_REVERSE_TIME, CONF_SCENES as CONF_SCENES, CONF_SETPOINT as CONF_SETPOINT, CONF_SK_NUM_TRIES as CONF_SK_NUM_TRIES, CONF_TRANSITION as CONF_TRANSITION, DIM_MODES as DIM_MODES, DOMAIN as DOMAIN, KEYS as KEYS, LED_PORTS as LED_PORTS, LOGICOP_PORTS as LOGICOP_PORTS, MOTOR_PORTS as MOTOR_PORTS, MOTOR_REVERSE_TIME as MOTOR_REVERSE_TIME, OUTPUT_PORTS as OUTPUT_PORTS, RELAY_PORTS as RELAY_PORTS, S0_INPUTS as S0_INPUTS, SETPOINTS as SETPOINTS, TEMP_CELSIUS as TEMP_CELSIUS, TEMP_FAHRENHEIT as TEMP_FAHRENHEIT, THRESHOLDS as THRESHOLDS, VARIABLES as VARIABLES, VAR_UNITS as VAR_UNITS
from .helpers import has_unique_host_names as has_unique_host_names, is_address as is_address
from homeassistant.components.climate import DEFAULT_MAX_TEMP as DEFAULT_MAX_TEMP, DEFAULT_MIN_TEMP as DEFAULT_MIN_TEMP
from homeassistant.const import CONF_ADDRESS as CONF_ADDRESS, CONF_BINARY_SENSORS as CONF_BINARY_SENSORS, CONF_COVERS as CONF_COVERS, CONF_HOST as CONF_HOST, CONF_LIGHTS as CONF_LIGHTS, CONF_NAME as CONF_NAME, CONF_PASSWORD as CONF_PASSWORD, CONF_PORT as CONF_PORT, CONF_SCENE as CONF_SCENE, CONF_SENSORS as CONF_SENSORS, CONF_SOURCE as CONF_SOURCE, CONF_SWITCHES as CONF_SWITCHES, CONF_UNIT_OF_MEASUREMENT as CONF_UNIT_OF_MEASUREMENT, CONF_USERNAME as CONF_USERNAME
from typing import Any

DOMAIN_DATA_BINARY_SENSOR: Any
DOMAIN_DATA_CLIMATE: Any
DOMAIN_DATA_COVER: Any
DOMAIN_DATA_LIGHT: Any
DOMAIN_DATA_SCENE: Any
DOMAIN_DATA_SENSOR: Any
DOMAIN_DATA_SWITCH: Any
DOMAIN_DATA_BASE: Any
BINARY_SENSORS_SCHEMA: Any
CLIMATES_SCHEMA: Any
COVERS_SCHEMA: Any
LIGHTS_SCHEMA: Any
SCENES_SCHEMA: Any
SENSORS_SCHEMA: Any
SWITCHES_SCHEMA: Any
CONNECTION_SCHEMA: Any
CONFIG_SCHEMA: Any



from homeassistant.core import split_entity_id as split_entity_id
from typing import Any

class EntityValues:
    _cache: Any
    _exact: Any
    _domain: Any
    _glob: Any
    def __init__(self, exact: Union[dict[str, dict[str, str]], None] = ..., domain: Union[dict[str, dict[str, str]], None] = ..., glob: Union[dict[str, dict[str, str]], None] = ...) -> None: ...
    def get(self, entity_id: str) -> dict[str, str]: ...
